#
# discovery.py
#
# Copyright (c) 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Bees Software.
#
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#

# Construct the capabilities used by the Discovery protocol.

from bees.tools.beesShell import *

an = nodes[0]

try:
    # Create some subdirectories
    an.capabilityMap().create("discovery")
    #                         ^^^^^^^^^^ name
    an.capabilityMap().create("discovery/protocol")
    #                                    ^^^^^^^^ subname
    an.capabilityMap().create("discovery/application")
    
    # Create a 'ClassSpace' spec defining the additional set of classes
    # we want the protocol to have access to.
    createClasses(an, "discovery/protocol/cs",
                  #^^^^^^^^^^^^^^^^^^^^^ capability name in the kernel.
                  [ "bees.core.resource.NodeOSNeighbor",
                    # Public key capability
                    "bees.core.security.PublicKey",
                    # Cryptographic signatures
                    "bees.core.security.Signature",
                    # Used to send/receive capabilities
                    "bees.core.CapabilityEnvelope",
                    "bees.core.CapabilityReference",
                    ])
    
    an.systemClass().create("discovery/application/cs",
                            "bees.core.ApplicationBDomain")
    
    an.versionString().create("discovery/protocol/version", "Discovery 2002")
    
    # Logger capabilities with different levels
    an.logger().create("discovery/protocol/logger.EMERG", "Discovery Log",
                       "emergency")
    an.logger().create("discovery/protocol/logger.DBG", "Discovery Log")
    an.logger().create("discovery/application/logger.EMERG",
                       "Discovery App Log", "emergency")
    an.logger().create("discovery/application/logger.DBG",
                       "Discovery App Log")
    
    # an.keyPairGenerator().create("discovery/keys/DSA", "DSA", 1024)
    # an.keyPairGenerator().create("discovery/keys/RSA", "RSA", 2048)
    
    # Write the caps out to the file
    an.capabilityMap("discovery").writeTo("discovery.cap")
finally:
    an.shutdown()
