#
# users.py
#
# Copyright (c) 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Bees Software.
#
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#

# Generate a users directory to run the demo applications.

import os

from bees.tools.beesShell import *

an = nodes[0]

try:
    an.capabilityMap().create("users")
    an.capabilityMap().create("users/demo")
    an.capabilityMap().create("users/demo/benchmark")
    an.capabilityMap().create("users/demo/classpath")
    an.capabilityMap().create("users/demo/health")
    an.capabilityMap().create("users/demo/health/keys")
    an.capabilityMap().create("users/demo/keys")
    an.capabilityMap().create("users/demo/meters")

    an.account().create("users/demo/account",
                        pairs={
        "name" : "Invader Zim",
        "email" : "zim@irk",
        })

    an.meter().create("users/demo/meters/cpu",
                      "users/demo/account",
                      countPermissions={
        "cpu.shares" : 1000,
        "cpu.threads" : 4,
        })

    an.meter().create("users/demo/meters/mem",
                      "users/demo/account",
                      countPermissions={
        "mem.pages" : 1000,
        })

    an.meter().create("users/demo/meters/capabilities",
                      "users/demo/account",
                      countPermissions={
        "capabilities.memory" : 32 * 1024,
        })

    an.fileSystemRoot().create("users/demo/home", os.curdir)

    createClasses(an, "users/demo/classpath/sensors.jar", [
        "kaffe.sensors.Sensor",
        "kaffe.sensors.SensorFeature",
        ])

    createPackages(an, "users/demo/classpath/sensors.jar", [
        "kaffe.sensors",
        ])

    an.file().create("users/demo/benchmark/flow.desc",
                     "benchmark.flow.desc",
                     fs="/users/demo/home")
    
    print "Generating keys (this can take awhile)..."
    print "  DSA"
    try:
        an.keyPairGenerator().create("users/demo/keys/DSA", "DSA", 1024)
    except MessageError, e:
        print "Unable to make DSA keys..."
    print "  RSA"
    try:
        an.keyPairGenerator().create("users/demo/keys/RSA", "RSA", 2048)
    except MessageError, e:
        print "Unable to make RSA keys..."

    an.file().create("users/demo/health/flow.desc",
                     "health.flow.desc",
                     fs="/users/demo/home")
    print "Generating more keys (this can take awhile)..."
    print "  DSA"
    try:
        an.keyPairGenerator().create("users/demo/health/keys/DSA", "DSA", 1024)
    except MessageError, e:
        print "Unable to make DSA keys..."
    print "  RSA"
    try:
        an.keyPairGenerator().create("users/demo/health/keys/RSA", "RSA", 2048)
    except MessageError, e:
        print "Unable to make RSA keys..."

    an.capabilityMap("users").writeTo("users.cap")
finally:
    an.shutdown()
