#
# bees.py
#
# Copyright (c) 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Bees Software.
#
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#

import types
import string

from jsi.message import *
from jsi.channel import *
from jsi.messageError import *

from info import *
from neighbor import *
from memoryPage import *
from capability import *
from systemClass import *
from systemPackage import *
from packages import *
from eventChannel import *
from node import *
from timerFrequency import *
from networkInterface import *
from networkService import *
from logger import *
from guardedString import *
from bdomainRegister import *
from capabilityMap import *
from handler import *
from clock import *
from versionString import *
from kernelObject import *
from keyPairGenerator import *
from readOnlyMemory import *
from cpuShare import *
from shares import *
from file import *
from fileSystemRoot import *
from addressRange import *
from nodeOSProtocolEnumeration import *
from externalChannel import *
from envelope import *
from publicKey import *
from meter import *
from account import *

BeesstdHandlers = [
    [ "object", "bees.core.kernel.KernelObjectStoreHandler" ],
    [ "capability", "bees.core.kernel.KernelCapabilities" ],
    [ "meter", "bees.core.resource.MeterHandler" ],
    [ "account", "bees.core.resource.AccountHandler" ],
    [ "bdomainRegister", "bees.core.kernel.BDomainRegisterHandler" ],
    [ "eventChannel", "bees.core.EventChannelHandler" ],
    [ "systemClass", "bees.core.resource.SystemClassHandler" ],
    [ "systemPackage", "bees.core.resource.SystemPackageHandler" ],
    [ "file", "bees.core.resource.FileHandler" ],
    [ "fileSystemRoot", "bees.core.resource.FileSystemRootHandler" ],
    [ "neighbor", "bees.core.resource.NodeOSNeighborHandler" ],
    [ "networkInterface", "bees.core.resource.NetworkInterfaceHandler" ],
    [ "networkService", "bees.core.resource.NetworkServiceHandler" ],
    [ "logger", "bees.core.resource.LoggerHandler" ],
    [ "node", "bees.core.NodeHandler" ],
    [ "clock", "bees.core.resource.ClockHandler" ],
    [ "versionString", "bees.core.security.VersionStringHandler" ],
    [ "keyPairGenerator", "bees.core.security.KeyPairGeneratorHandler" ],
    ]

class Bees:
    def __init__(self, chan):
        self.channel = chan
        self.msg = Message()
        for h in BeesstdHandlers:
            try:
                self.handler(h[0]).get()
            except MessageError:
                try:
                    self.handler().create(h[0], className=h[1])
                except:
                    pass

    def disconnect(self):
        self.channel.disconnect()

    def addPermissions(self,
                       permissions={},
                       countPermissions={},
                       intPermissions={},
                       minIntPermissions={},
                       maxIntPermissions={},
                       rangePermissions={},
                       floatPermissions={},
                       minFloatPermissions={},
                       maxFloatPermissions={},
                       enumPermissions={},
                       ipPermissions={},
                       filePermissions={}):
        for permission in permissions.keys():
            self.msg.add("permission",
                         permission +
                         "=" +
                         permissions[permission])
        for permission in countPermissions.keys():
            self.msg.add("countPermission",
                         permission +
                         "=" +
                         str(countPermissions[permission]))
        for permission in intPermissions.keys():
            self.msg.add("intPermission",
                         permission +
                         "=" +
                         str(intPermissions[permission]))
        for permission in minIntPermissions.keys():
            self.msg.add("minIntPermission",
                         permission +
                         "=" +
                         str(minIntPermissions[permission]))
        for permission in maxIntPermissions.keys():
            self.msg.add("maxIntPermission",
                         permission +
                         "=" +
                         str(maxIntPermissions[permission]))
        for permission in rangePermissions.keys():
            self.msg.add("rangePermission",
                         permission +
                         "=" +
                         rangePermissions[permission])
        for permission in floatPermissions.keys():
            self.msg.add("floatPermission",
                         permission +
                         "=" +
                         str(floatPermissions[permission]))
        for permission in minFloatPermissions.keys():
            self.msg.add("minFloatPermission",
                         permission +
                         "=" +
                         str(minFloatPermissions[permission]))
        for permission in maxFloatPermissions.keys():
            self.msg.add("maxFloatPermission",
                         permission +
                         "=" +
                         str(maxFloatPermissions[permission]))
        for permission in enumPermissions.keys():
            self.msg.add("enumPermission",
                         permission +
                         "=" +
                         str(enumPermissions[permission]))
        for permission in ipPermissions.keys():
            self.msg.add("ipPermission",
                         permission +
                         "=" +
                         ipPermissions[permission])
        for permission in filePermissions.keys():
            self.msg.add("filePermission",
                         permission +
                         "=" +
                         filePermissions[permission])

    def send(self):
        self.msg.reverseSpecifiers()
        what = self.msg.getWhat()
        buf = self.msg.flatten()
        self.msg.clear()
        self.channel.send(buf)
        if what == JSI_SHUTDOWN:
            return
        else:
            buf = self.channel.recv()
            reply = Message()
            reply.unflatten(buf)
            if reply.getWhat() == JSI_ERROR:
                raise MessageError(reply)
            else:
                return reply

    def sendMessage(self, req):
        what = req.getWhat()
        buf = req.flatten()
        self.channel.send(buf)
        if what == JSI_SHUTDOWN:
            return
        else:
            buf = self.channel.recv()
            reply = Message()
            reply.unflatten(buf)
            if reply.getWhat() == JSI_ERROR:
                raise MessageError(reply)
            else:
                return reply

    def shutdown(self):
        self.msg.setWhat(JSI_SHUTDOWN)
        self.send()

    def list(self):
        self.msg.setWhat(JSI_LIST_PROPERTIES)
        reply = self.send()
        return reply.getIdentifiers()

    def info(self):
        return Info(self)
    
    def handler(self, name=""):
        return Handler(self, name)
    
    def kernelObject(self, id=-1):
        return KernelObject(self, id)
    
    def bdomainRegister(self, name=""):
        return BDomainRegister(self, name)
    
    def neighbor(self, name=""):
        return Neighbor(self, name)

    def externalChannel(self, name=""):
        return ExternalChannel(self, name)

    def memoryPage(self, name=""):
        return MemoryPage(self, name)

    def systemClass(self, name=""):
        return SystemClass(self, name)

    def systemPackage(self, name=""):
        return SystemPackage(self, name)

    def eventChannel(self, name):
        return EventChannel(self, name)

    def guardedString(self):
        return GuardedString(self)

    def capability(self, name = ""):
        return Capability(self, name)

    def capabilityMap(self, name = None):
        return CapabilityMap(self, name)

    def envelope(self, name = None):
        return Envelope(self, name)

    def node(self, name = ""):
        return Node(self, name)

    def timerFrequency(self, name=""):
        return TimerFrequency(self, name)

    def logger(self, name=""):
        return Logger(self, name)

    def networkInterface(self, name=""):
        return NetworkInterface(self, name)

    def networkService(self, name=""):
        return NetworkService(self, name)

    def clock(self, name=""):
        return Clock(self, name)

    def versionString(self, name=""):
        return VersionString(self, name)

    def keyPairGenerator(self):
        return KeyPairGenerator(self)

    def readOnlyMemory(self, name = ""):
        return ReadOnlyMemory(self, name)

    def cpuShare(self, name = ""):
        return CPUShare(self, name)

    def shares(self, name = ""):
        return Shares(self, name)

    def file(self, name = ""):
        return File(self, name)

    def fileSystemRoot(self, name = ""):
        return FileSystemRoot(self, name)

    def publicKey(self, name):
        return PublicKey(self, name)

    def meter(self, name = ""):
        return Meter(self, name)

    def account(self, name = ""):
        return Account(self, name)
