#
# envelope.py
#
# Copyright (c) 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Bees Software.
#
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#

from bees import *

import sys

class Envelope:
    def __init__(self, bees, name = None):
        self.bees = bees
        if name != None:
            self.bees.msg.pushSpecifier("capability", name)
        else:
            self.bees.msg.pushSpecifier("capability")

    def create(self, name, capability):
        self.bees.msg.setWhat(JSI_CREATE_PROPERTY)
        self.bees.msg.add("name", name)
        self.bees.msg.add("capability", capability)
        self.bees.send()

    def getPermissions(self):
        self.bees.msg.setWhat(JSI_GET_PROPERTY)
        self.bees.msg.pushSpecifier("permissions")
        reply = self.bees.send()
        return reply

    def grantPermissions(self,
                         countPermissions={},
                         permissions={},
                         intPermissions={},
                         minIntPermissions={},
                         maxIntPermissions={},
                         rangePermissions={},
                         floatPermissions={},
                         minFloatPermissions={},
                         maxFloatPermissions={},
                         enumPermissions={},
                         ipPermissions={},
                         filePermissions={}):
        self.bees.msg.setWhat(JSI_EXECUTE_PROPERTY)
        self.bees.msg.pushSpecifier("grantPermissions")
        self.bees.addPermissions(permissions=permissions,
                                 countPermissions=countPermissions,
                                 intPermissions=intPermissions,
                                 minIntPermissions=minIntPermissions,
                                 maxIntPermissions=maxIntPermissions,
                                 rangePermissions=rangePermissions,
                                 floatPermissions=floatPermissions,
                                 minFloatPermissions=minFloatPermissions,
                                 maxFloatPermissions=maxFloatPermissions,
                                 enumPermissions=enumPermissions,
                                 ipPermissions=ipPermissions,
                                 filePermissions=filePermissions)
        self.bees.send()

    def revokePermissions(self,
                          permissions={},
                          countPermissions={},
                          intPermissions={},
                          minIntPermissions={},
                          maxIntPermissions={},
                          rangePermissions={},
                          floatPermissions={},
                          minFloatPermissions={},
                          maxFloatPermissions={},
                          enumPermissions={},
                          ipPermissions={},
                          filePermissions={}):
        self.bees.msg.setWhat(JSI_EXECUTE_PROPERTY)
        self.bees.msg.pushSpecifier("revokePermissions")
        self.bees.addPermissions(permissions=permissions,
                                 countPermissions=countPermissions,
                                 intPermissions=intPermissions,
                                 minIntPermissions=minIntPermissions,
                                 maxIntPermissions=maxIntPermissions,
                                 rangePermissions=rangePermissions,
                                 floatPermissions=floatPermissions,
                                 minFloatPermissions=minFloatPermissions,
                                 maxFloatPermissions=maxFloatPermissions,
                                 enumPermissions=enumPermissions,
                                 ipPermissions=ipPermissions,
                                 filePermissions=filePermissions)
        self.bees.send()

    def boundPermissions(self,
                         permissions={},
                         countPermissions={},
                         intPermissions={},
                         minIntPermissions={},
                         maxIntPermissions={},
                         rangePermissions={},
                         floatPermissions={},
                         minFloatPermissions={},
                         maxFloatPermissions={},
                         enumPermissions={},
                         ipPermissions={},
                         filePermissions={}):
        self.bees.msg.setWhat(JSI_EXECUTE_PROPERTY)
        self.bees.msg.pushSpecifier("boundPermissions")
        self.bees.addPermissions(permissions=permissions,
                                 countPermissions=countPermissions,
                                 intPermissions=intPermissions,
                                 minIntPermissions=minIntPermissions,
                                 maxIntPermissions=maxIntPermissions,
                                 rangePermissions=rangePermissions,
                                 floatPermissions=floatPermissions,
                                 minFloatPermissions=minFloatPermissions,
                                 maxFloatPermissions=maxFloatPermissions,
                                 enumPermissions=enumPermissions,
                                 ipPermissions=ipPermissions,
                                 filePermissions=filePermissions)
        self.bees.send()
