#
# file.py
#
# Copyright (c) 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Bees Software.
#
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#

from bees import *

class File:
    def __init__(self, bees, name = ""):
        self.bees = bees
        if not name == "":
            self.bees.msg.pushSpecifier("file", name)

    def create(self, name, path, fs=None, filePermissions={
        "file" : "read, write, append",
        }, permissions={
        "file.length" : "read",
        "file.lastModified" : "read, write",
        "file.delete" : "execute",
        }):
        self.bees.msg.setWhat(JSI_CREATE_PROPERTY)
        self.bees.msg.pushSpecifier("file")
        self.bees.msg.add("name", name)
        self.bees.msg.add("path", path)
        if fs != None:
            self.bees.msg.add("fs", fs)
        for permission in filePermissions.keys():
            self.bees.msg.add("filePermission",
                              permission +
                              "=" +
                              filePermissions[permission])
        for permission in permissions.keys():
            self.bees.msg.add("permission",
                              permission +
                              "=" +
                              permissions[permission])
        reply = self.bees.send()
        return reply.find("result")

    def getPath(self):
        self.bees.msg.setWhat(JSI_GET_PROPERTY)
        self.bees.msg.pushSpecifier("path")
        reply = self.bees.send()
        return reply.find("result")
