#
# properties.py
#
# Copyright (c) 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Bees Software.
#
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#

import re
import shlex
import string
import StringIO

class Properties:
    def __init__(self):
        self.props = {}

    def read(self, data):
        lines = re.split("\n", data)
        for line in lines:
            comments = re.split("[#!]", line)
            line = comments[0]
            pair = string.split(line, '=', 1)
            if len(pair) == 2:
                self.props[string.strip(pair[0])] = string.strip(pair[1])

    def load(self, filename):
        file = open(filename)
        data = file.read()
        self.read(data)

    def get(self, name, defaultValue=None):
        try:
            return self.props[name]
        except KeyError, e:
            if defaultValue == None:
                raise e
            else:
                return defaultValue

    def getList(self, name, defaultValue=None):
        try:
            value = self.props[name]
            sio = StringIO.StringIO(value)
            shl = shlex.shlex(sio)
            shl.whitespace = shl.whitespace + ","
            shl.wordchars = shl.wordchars + ".-/"
            retval = []
            while 1:
                tok = shl.get_token()
                if tok == "":
                    break
                if tok[0] == "\"":
                    tok = tok[1:len(tok) - 1]
                retval.append(tok)
            return retval
        except KeyError, e:
            if defaultValue == None:
                raise e
            else:
                return defaultValue

    def getPrefixList(self, name):
        retval = []
        for prop in self.props.keys():
            if string.find(prop, name) == 0:
                retval.append(prop)
        return retval

    def set(self, name, value):
        self.props[name] = value

    def __repr__(self):
        return `self.props`
