#
# beesUtil.py
#
# Copyright (c) 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Bees Software.
#
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#

from bees.bees import *

def createClasses(node, baseName, classes=[]):
    if not node.capability(baseName).exists():
        node.capabilityMap().create(baseName)
    for cl in classes:
        node.systemClass().create(baseName + "/" + cl, cl)

def createPackages(node, baseName, packages=[]):
    if not node.capability(baseName).exists():
        node.capabilityMap().create(baseName)
    for pack in packages:
        node.systemPackage().create(baseName + "/" + pack, pack)

def createUDPMulticastNeighbor(node, name, port,
                               localAddress = "127.0.0.1",
                               address = "239.192.0.50",
                               nic = "if",
                               neighborMask = "*"):
    return node.neighbor().create(name,
                                  nic + "/ipv4/udp",
                                  (neighborMask
                                   + ":"
                                   + `port`
                                   + ":"
                                   + address
                                   + ":"
                                   + "*"),
                                  nic + "/ipv4/udp",
                                  ("*"
                                   + ":"
                                   + `port`
                                   + ":"
                                   + address
                                   + ":"
                                   + "*"))

def createUDPNeighbor(node,
                      name,
                      localPort,
                      neighborPort,
                      localAddress = "127.0.0.1",
                      neighborAddress = "127.0.0.1",
                      nic = "if"):
    if localPort == 0:
        localPortString = "*"
    else:
        localPortString = `localPort`
    return node.neighbor().create(name,
                                  nic + "/ipv4/udp",
                                  (neighborAddress
                                   + ":"
                                   + localPortString
                                   + ":"
                                   + localAddress
                                   + ":"
                                   + `neighborPort`),
                                  nic + "/ipv4/udp",
                                  ("*"
                                   + ":"
                                   + `neighborPort`
                                   + ":"
                                   + neighborAddress
                                   + ":"
                                   + localPortString))

def createETHNeighbor(node,
                      name,
                      iface,
                      localAddress,
                      neighborAddress,
                      ethType):
    return node.neighbor().create(name,
                                  iface,
                                  (localAddress
                                   + ":"
                                   + ethType
                                   + ":"
                                   + neighborAddress),
                                  iface,
                                  (neighborAddress
                                   + ":"
                                   + ethType
                                   + ":"
                                   + localAddress))

def createPrimaryBDomainRegister(nodes):
    map(lambda node: node.bdomainRegister().create("primary"), nodes)

def createNICs(nodes):
    map(createUDPNetworkInterface, nodes, ["nic"] * len(nodes), range(9000, 9000 + len(nodes)))
