#
# discoveryTools.py
#
# Copyright (c) 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Bees Software.
#
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#

def loadDiscoveryCapabilities(nodes,
                              directory="discovery",
                              filename="discovery.cap",
                              password=""):
    "Load the discovery capabilities from a file."
    map(lambda node, directory:
        node.capabilityMap().create(directory),
        nodes,
        [directory] * len(nodes))
    map(lambda node, directory, filename, password:
        node.capabilityMap(directory).readFrom(filename, password),
        nodes,
        [directory] * len(nodes),
        [filename] * len(nodes),
        [password] * len(nodes))

def loadDiscoveryKeys(nodes,
                      filename,
                      password,
                      directory="discovery/keys"):
    "Load the discovery keys from a file."
    map(lambda node: node.capabilityMap().create(directory), nodes)
    map(lambda node: (node.capabilityMap(directory).
                      readFrom(filename, password)), nodes)

def computeDiscoveryCapabilities(directory="discovery"):
    """Map of capabilities stored in the kernels to arguments passed to the
    newflow/domain/whatever"""
    retval = {
        "user/broadcastNeighbor" : directory + "/protocol/broadcastNeighbor",
        # ^^^ domain name           ^^^ kernel name
        "user/basicTimerFrequency" : directory + "/protocol/tf",
        "node" : "node",
        "logger" : directory + "/application/logger.DBG",
        "user/protocolLogger" : directory + "/protocol/logger.DBG",
        "user/protocolClasses" : directory + "/protocol/cs",
        }
    return retval

def startDiscovery(nodes, directory="discovery"):
    "Create the app flow"
    map(lambda node, id: (node.bdomainRegister("primary").bdomain().
                          create(direcotry + "/application/ec",
                                 # ^^^ The flows communication channel
                                 "bees.core.ApplicationBDomain",
                                 # ^^^ The main class
                                 args=["apps.discovery.DiscoveryApplication",
                                       `id`]
                                 #      ^^^ The app to start up
                                 )),
        nodes, range(0, len(nodes)))
    # Pass caps and set the flow in motion
    map(lambda node: (node.eventChannel(directory + "/application/ec").
                      #                  ^^^ Flow to talk to
                      passCapability(named = discoveryNamed,
                                     # ^^^ The named caps to pass through
                                     extras = [directory + "/application/cs"
                                               # ^^^ Extra/unnamed caps
                                               ])),
        nodes)
