/*
 * BenchmarkProtocol.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package apps.benchmark;

import java.io.FileNotFoundException;

import bees.core.Panic;
import bees.core.Protocol;
import bees.core.DLProtocol;
import bees.core.IDTranslationProtocol;

import bees.core.resource.Logger;

import bees.core.security.Permission;
import bees.core.security.PermissionSet;
import bees.core.security.CountPermission;
import bees.core.security.MinimumIntegerPermission;

public class BenchmarkProtocol
    extends Protocol
{
    public BenchmarkProtocol()
    {
	try
	{
	    this.startProtocolDefn();
	    {
		this.addFile("apps/benchmark/protocol.properties");

		this.addCode("apps.benchmark.BenchmarkCapsule");
		this.addCode("apps.benchmark.BenchmarkParameters");
		
		this.setBootStrap("apps.benchmark.BenchmarkBootCapsule",
				  new PermissionSet(new Permission[] {
				      new CountPermission(
					"transformTo.apps.benchmark."
					+ "PrimerCapsule",
					1),
				      new CountPermission(
					"transformTo.apps.benchmark."
					+ "StatsCapsule",
					1),
				  }));
		this.addCapsule("apps.benchmark.PrimerCapsule",
				new PermissionSet(new Permission[] {
				    new CountPermission("initial", 1),
				    new CountPermission("forwards", 1),
				    new CountPermission("returns", 1),
				      new CountPermission(
					"transformTo.apps.benchmark."
					+ "StatsCapsule",
					1),
				    
				    new CountPermission("cached", 1),
				    new MinimumIntegerPermission("interval",
								 100),
				    
				    new CountPermission("threadCount", 1),
				    new CountPermission("bufferCount", 2),
				}));
		this.addCapsule("apps.benchmark.StatsCapsule",
				new PermissionSet(new Permission[] {
				    new CountPermission("returns", 1),
				    new CountPermission("forwards", 1),
				    
				    new CountPermission("cached", 1),
				    new MinimumIntegerPermission("interval",
								 100),
				    
				    new CountPermission("threadCount", 1),
				    new CountPermission("bufferCount", 10),
				    
				    new CountPermission(
					"transformTo.apps.benchmark."
					+ "SendCapsule",
					1),
				    new CountPermission(
					"transformTo.apps.benchmark."
					+ "RelayCapsule",
					1),
				}));
		this.addCapsule("apps.benchmark.SendCapsule",
				new PermissionSet(new Permission[] {
				    new CountPermission("returns",
							BenchmarkSession.
							MAX_RUN_LENGTH),
				    
				    new CountPermission("threadCount", 1),
				    new CountPermission("bufferCount", 10),
				}));
		this.addCapsule("apps.benchmark.RelayCapsule",
				new PermissionSet(new Permission[] {
				    new CountPermission("returns",
							BenchmarkSession.
							MAX_RUN_LENGTH),
				    new CountPermission("forwards", 1),
				    
				    new CountPermission("threadCount", 1),
				    new CountPermission("bufferCount", 10),
				}));

		this.setSession("apps.benchmark.BenchmarkSession");
		
		this.addCompanion(new DLProtocol());
		this.addCompanion(new IDTranslationProtocol());
	    }
	    this.endProtocolDefn();
	}
	catch(FileNotFoundException e)
	{
	    throw new Panic("Unable to access file", e);
	}
	catch(ClassNotFoundException e)
	{
	    throw new Panic("Unable to access classes", e);
	}
    }

    public String toString()
    {
	return "BenchmarkProtocol["
	    + super.toString()
	    + "]";
    }
}
