/*
 * MinimalCapsule.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package apps.benchmark;

import bees.core.Xdr;
import bees.core.Node;
import bees.core.Capsule;

import bees.core.resource.Logger;

public final class MinimalCapsule
    extends Capsule
{
    private final static int MAX_PACKETS = 300000;
    
    private final static int STAT_INTERVAL = 1000;
    
    static long start;
    static long last;
    static long lastStat;
    static long packetCount;
    
    public MinimalCapsule()
    {
    }
    
    public void decode(Xdr xdr)
    {
    }

    public void encode(Xdr xdr)
    {
    }
    
    public void evaluate(Node node)
    {
	long current, diff;

	packetCount += 1;
	current = BenchmarkBootCapsule.clock.current();
	if( last == 0 )
	{
	    last = current;
	    start = current;
	    lastStat = current;
	}
	last = current;
	diff = current - lastStat;
	if( diff >= STAT_INTERVAL )
	{
	    long total, secs, usecs;
	    
	    total = current - start;
	    secs = total / 1000;
	    usecs = (total % 1000) * 10;
	    Logger.log("cycle "
		       + packetCount
		       + ":\n  secs: "
		       + secs
		       + "\n  usecs: "
		       + usecs
		       + "\n  pps: "
		       + (packetCount / secs));
	    lastStat = current;
	}
	this.addToPool();
    }

    public String toString()
    {
	return "MinimalCapsule["
	    + super.toString()
	    + "]";
    }
}
