/*
 * MulticastDataProtocol.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package apps.multicast;

public class MulticastDataProtocol
    extends Protocol
    implements CapsuleCompanionProtocol
{
    public MulticastDataProtocol()
    {
	try
	{
	    super.startProtocolDefn();
	    {
		this.addFile("apps/multicast/protocol.properties");
		
		this.addCapsule("apps.multicast.MulticastDataCapsule",
				new PermissionSet(new Permission[] {
				    new CountPermission("neighborhood", 1),
				    
				    new CountPermission("threadCount", 1),
				    new CountPermission("bufferCount", 5),
				}));
		this.setSession("apps.multicast.MulticastDataSession");

		this.addCompanion(new DLProtocol());
	    }
	    super.endProtocolDefn();
	}
	catch(FileNotFoundException e)
	{
	    Logger.log(e);
	    throw new Panic("Unable to access file", e);
	}
	catch(ClassNotFoundException e)
	{
	    Logger.log(e);
	    throw new Panic("Unable to access classes", e);
	}
	catch(Throwable th)
	{
	    Logger.log(th);
	    throw new Panic("Big problem", th);
	}
    }
    
    public String toString()
    {
	return "MulticastDataProtocol["
	    + super.toString()
	    + "]";
    }
}
