/*
 * MulticastCapsule.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package apps.pathfinder;

import bees.core.Node;
import bees.core.Capsule;
import bees.core.EncodingException;

import bees.core.resource.Logger;

/**
 * A MulticastCapsule is a base class for Capsule types that will be multicast
 * from the server node to the clients.
 */
public abstract class MulticastCapsule
    extends Capsule
{
    /**
     * Construct an empty MulticastCapsule.
     */
    public MulticastCapsule()
    {
    }

    /**
     * @param node The current Node object.
     * @param pfs The PathfinderSession for this flow.
     */
    public void evaluate(Node node, PathfinderSession pfs)
    {
	try
	{
	    pfs.getChildren().send(this);
	}
	catch(EncodingException e)
	{
	    Logger.log(e);
	}
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
	return "MulticastCapsule["
	    + super.toString()
	    + "]";
    }
}
