/*
 * AsymmetricSealFactory.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import bees.core.kernel.KernelObjectCoroutine;

import bees.core.bdomain.BDomain;

public final class AsymmetricSealFactory
    extends Capability
{
    private BDomain bdomain;
    
    public AsymmetricSealFactory()
    {
    }

    protected synchronized void fromBytes(byte flattened[])
	throws Exception
    {
	super.fromBytes(flattened);
	
	this.bdomain = BDomain.currentBDomain();
    }

    public void revoke()
    {
	super.clear();

	this.bdomain = null;
    }

    public synchronized SealPair create(String comment)
    {
	SealPair retval = null;
	Capability caps[];

	caps = new Capability[] {
	    new AsymmetricSealer(),
	    new AsymmetricUnsealer(),
	};
	if( KernelObjectCoroutine.create(caps,
					 this.bdomain.getBDomainCoroutine(),
					 new byte[0],
					 comment,
					 null) != null )
	{
	    retval = new SealPair((Sealer)caps[0], (Unsealer)caps[1]);
	}
	return retval;
    }

    public synchronized SealPair create()
    {
	return this.create("AsymmetricSeal");
    }
    
    public String toString()
    {
	return "AsymmetricSealFactory["
	    + super.toString()
	    + "]";
    }
}
