/*
 * Authorizer.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import bees.core.bdomain.CapabilityTree;

/**
 * Interface for applications that wish to handle authorization requests from
 * protocols.
 *
 * @see bees.core.AuthorizationCoroutine
 */
public interface Authorizer
{
    /**
     * Call back used to handle an AuthorizationCoroutine.beginManagement
     * event.
     *
     * @param ce An envelope containing the event channel of the requester.
     * @param sessionID The protocol session identifier that wishes to be
     * managed.
     */
    void beginManagement(CapabilityEnvelope ce, TypeID sessionID);
    
    /**
     * Call back used to handle an
     * AuthorizationCoroutine.beginExtendedManagement event.
     *
     * @param ce An envelope containing the event channel of the requester.
     * @param sessionID The protocol session identifier that wishes to be
     * managed.
     */
    void beginExtendedManagement(CapabilityEnvelope ce, TypeID sessionID);

    /**
     * Call back used to terminate management for the given protocol.
     *
     * @param ce An envelope containing the event channel of the requester.
     * @param sessionID The protocol session identifier that wishes management
     * to end.
     */
    void endManagement(CapabilityEnvelope ce, TypeID sessionID);
    
    /**
     * Call back used to handle an AuthorizationCoroutine.authorize event.
     *
     * @param requester The envelope containing the event channel.
     * @param src The name of the capability, relative to the Authenticator's
     * internal ObjectTree.
     * @param dst The name to be placed in the CapabilityEnvelopes.
     * @param auth Authorization data/signatures.
     * @return An array of envelopes containing the requested capabilities.
     */
    CapabilityTree authorize(CapabilityEnvelope requester,
			     String src, String dst, byte auth[]);
}
