/*
 * EventChannelHandler.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import java.util.NoSuchElementException;

import edu.utah.janosvm.kit.comm.jsi.JSIMessage;
import edu.utah.janosvm.kit.comm.jsi.JSIPropertyInfo;
import edu.utah.janosvm.kit.comm.jsi.MissingPairException;

import bees.core.bdomain.BDomain;

import bees.core.kernel.KernelCapabilities;
import bees.core.kernel.KernelObjectCoroutine;

import bees.core.resource.CapabilityHandler;

/**
 * The EventChannelHandler is a JSIHandler that can interact with EventChannel
 * capabilities.
 */
public final class EventChannelHandler
    extends CapabilityHandler
{
    /**
     * The set of supported properties to be added to a JSIMessage.GET_SUITES
     * request.
     */
    private static final JSIPropertyInfo JSI_PROPERTIES[] = {
	new JSIPropertyInfo("eventChannel",
			    (1 << JSIMessage.GET_PROPERTY),
			    "name:string",
			    "Get the value of an EventChannel capability.\n"),
    };

    /**
     * Construct an empty EventChannelHandler object.
     */
    public EventChannelHandler()
    {
    }

    /**
     * @see bees.core.resource.CapabilityHandler#getCapabilityClass()
     */
    public Class getCapabilityClass()
    {
	return EventChannel.class;
    }

    /**
     * @see bees.core.resource.CapabilityHandler#createCapability(JSIMessage, String, String)
     */
    public Object createCapability(JSIMessage jm,
				   String name,
				   String comment)
    {
	return null;
    }
    
    /**
     * @see edu.utah.janosvm.kit.comm.jsi.JSIHandler#getSuites(JSIMessage)
     */
    public void getSuites(JSIMessage jm)
    {
	jm.add("result", JSI_PROPERTIES);
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
	return "EventChannelHandler["
	    + super.toString()
	    + "]";
    }
}
