/*
 * ExternalCapsuleEvent.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import edu.utah.janos.nodeos.BufferHandle;

/**
 * An BeesEvent used to deliver the contents of an ExternalCapsule to another
 * domain.
 */
public final class ExternalCapsuleEvent
    extends BeesEvent
{
    /**
     * The body of the ExternalCapsule.
     */
    private BufferHandle body;

    /**
     * The set of CapabilityEnvelopes passed to the domain.
     */
    private CapabilityEnvelope ce[];

    /**
     * The set of CapabilityReferences passed to the domain.
     */
    private CapabilityReference cr[];

    /**
     * Construct an empty ExternalCapsuleEvent.
     */
    public ExternalCapsuleEvent()
    {
    }

    /**
     * @param body The body of the capsule.
     * @return this
     */
    public ExternalCapsuleEvent setBody(BufferHandle body)
    {
	this.body = body;
	return this;
    }

    /**
     * @return The body of the capsule.
     */
    public BufferHandle getBody()
    {
	return this.body;
    }

    /**
     * @param ce The set of CapabilityEnvelopes passed to the domain.
     */
    public ExternalCapsuleEvent setEnvelopes(CapabilityEnvelope ce[])
    {
	this.ce = ce;
	return this;
    }

    /**
     * @return The set of CapabilityEnvelopes passed to the domain.
     */
    public CapabilityEnvelope[] getEnvelopes()
    {
	return this.ce;
    }

    /**
     * @param ce The set of CapabilityReferences passed to the domain.
     */
    public ExternalCapsuleEvent setReferences(CapabilityReference cr[])
    {
	this.cr = cr;
	return this;
    }

    /**
     * @return The set of CapabilityReferences passed to the domain.
     */
    public CapabilityReference[] getReferences()
    {
	return this.cr;
    }

    public Object clone()
    {
	Object retval = super.clone();
	ExternalCapsuleEvent ce;

	ce = (ExternalCapsuleEvent)retval;
	if( this.body != null )
	{
	    ce.body = BufferHandle.create(this.body);
	}
	if( this.ce != null )
	{
	    int lpc;
	    
	    ce.ce = new CapabilityEnvelope[this.ce.length];
	    for( lpc = 0; lpc < this.ce.length; lpc++ )
	    {
		if( this.ce[lpc] != null )
		    ce.ce[lpc] = (CapabilityEnvelope)this.ce[lpc].clone();
	    }
	}
	if( this.cr != null )
	{
	    int lpc;
	    
	    ce.cr = new CapabilityReference[this.cr.length];
	    for( lpc = 0; lpc < this.cr.length; lpc++ )
	    {
		if( this.cr[lpc] != null )
		    ce.cr[lpc] = (CapabilityReference)this.cr[lpc].clone();
	    }
	}
	return retval;
    }

    public String toString()
    {
	return "ExternalCapsuleEvent["
	    + super.toString()
	    + "; body="
	    + this.body
	    + "; ce="
	    + this.ce
	    + "; cr="
	    + this.cr
	    + "]";
    }
}
