/*
 * FlowByteArrayType.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import java.util.Hashtable;

import bees.core.bdomain.BDomainLocal;

import bees.util.MD5;

final class FlowByteArrayType
{
    private static final BDomainLocal domainFlowByteArray = new BDomainLocal() {
	    protected Object initialValue()
	    {
		return new Hashtable();
	    }
	};
    
    private static final BDomainLocal domainFlows = new BDomainLocal() {
	    protected Object initialValue()
	    {
		return new Hashtable();
	    }
	};
    
    static Hashtable getBDomainFlowByteArray()
    {
	return (Hashtable)domainFlowByteArray.get();
    }

    static void putBDomainFlowByteArray(FlowByteArrayType fct)
    {
	Hashtable ht = (Hashtable)domainFlowByteArray.get();

	synchronized( ht )
	{
	    if( !ht.containsKey(fct.flowByteArrayID) )
	    {
		Hashtable sub;
		
		ht.put(fct.flowByteArrayID, fct);
		ht = (Hashtable)domainFlows.get();
		if( (sub = (Hashtable)ht.get(fct.ft.getFlowID())) == null )
		{
		    sub = new Hashtable();
		    ht.put(fct.ft.getFlowID(), sub);
		}
		sub.put(fct.ct.getByteArrayID(), fct);
	    }
	}
    }

    static FlowByteArrayType getBDomainFlowByteArray(TypeID domainByteArrayID)
    {
	Hashtable ht = (Hashtable)domainFlowByteArray.get();
	FlowByteArrayType retval;
	
	retval = (FlowByteArrayType)ht.get(domainByteArrayID);

	return retval;
    }

    static FlowByteArrayType getBDomainFlowByteArray(TypeID flowID, TypeID baID)
    {
	Hashtable ht = (Hashtable)domainFlows.get();
	FlowByteArrayType retval = null;

	synchronized( domainFlowByteArray.get() )
	{
	    if( (ht = (Hashtable)ht.get(flowID)) != null )
		retval = (FlowByteArrayType)ht.get(baID);
	}
	return retval;
    }

    private FlowType ft;
    private ByteArrayType ct;
    private TypeID flowByteArrayID;

    FlowByteArrayType()
    {
    }

    FlowByteArrayType setFlowType(FlowType ft)
    {
	this.ft = ft;
	return this;
    }

    FlowType getFlowType()
    {
	return this.ft;
    }
    
    FlowByteArrayType setByteArrayType(ByteArrayType ct)
    {
	this.ct = ct;
	return this;
    }

    ByteArrayType getByteArrayType()
    {
	return this.ct;
    }

    TypeID getFlowByteArrayID()
    {
	return this.flowByteArrayID;
    }

    FlowByteArrayType snapshotFlowByteArrayType()
    {
	MD5 digest = new MD5();
	
	digest.update(this.ft.getFlowID().getHash());
	digest.update(this.ct.getByteArrayID().getHash());
	this.flowByteArrayID = new TypeID(digest.hash());
	return this;
    }
    
    public String toString()
    {
	return "FlowByteArrayType[ft="
	    + this.ft
	    + "; ct="
	    + this.ct
	    + "; domainCodeID="
	    + this.flowByteArrayID
	    + "]";
    }
}
