/*
 * IDTranslatorCapsule.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import java.io.IOException;

import bees.core.resource.Logger;

final class IDTranslatorCapsule
    extends Capsule
{
    private boolean resolved = false;
    private TypeID flowID;
    
    IDTranslatorCapsule()
    {
    }

    public void encode(Xdr xdr)
    {
	xdr.PUT(this.resolved);
	if( this.resolved )
	{
	    xdr.PUT(this.flowID);
	}
    }

    public void decode(Xdr xdr)
    {
	this.resolved = xdr.BOOLEAN();
	if( this.resolved )
	{
	    this.flowID = xdr.TYPEID();
	}
    }

    public void evaluate(Node node)
    {
	if( this.resolved )
	{
	    UnknownCapsuleReceiver ucr;
	    ExternalCapsule ec;
	    Neighbor source;
	    Xdr xdr;

	    source = this.getSource();
	    ucr = ((UnknownNeighbor)source).getUnknownCapsuleReceiver();
	    ucr.cacheRecentTranslation(this.getSpecializer(), this.flowID);
	    ec = new ExternalCapsule(new CapabilityReference[] {
		new CapabilityReference(source.getNeighborImpl()),
	    }).init();
	    xdr = ec.getXDR();
	    xdr.PUT(IDTranslatorSession.TYPE_NEW_FLOW);
	    xdr.PUT(this.flowID);
	    ((IDTranslatorSession)this.getSession()).notifyInterests(ec);
	}
	else if( this.getCapsuleType().getSpecializedCapsuleID() != null )
	{
	    Logger.log("Translating...");
	    this.resolved = true;
	    this.flowID = this.getCapsuleType().getFlowType().getFlowID();
	    Logger.log("Map "
		       + this.getSpecializer()
		       + " -> "
		       + this.flowID);
	    try
	    {
		this.getSource().send(this);
	    }
	    catch(EncodingException e)
	    {
		Logger.log(e);
	    }
	    catch(IOException e)
	    {
		Logger.log(e);
	    }
	}
	else
	{
	    /* XXX What would this be? */
	}
	this.addToPool();
    }

    public String toString()
    {
	return "IDTranslatorCapsule["
	    + super.toString()
	    + "; resolved="
	    + this.resolved
	    + "; flowID="
	    + this.flowID
	    + "]";
    }
}
