/*
 * IDTranslatorPresentation.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

/**
 * An IDTranslatorPresentation interacts with the IDTranslatorSession in the
 * flow domain.
 */
public abstract class IDTranslatorPresentation
    extends ExtendedProtocolPresentation
{
    /**
     * Construct an empty IDTranslatorPresentation.
     */
    public IDTranslatorPresentation()
    {
    }

    public void userReceive(Node node, int method, ExternalCapsule ec)
    {
	Xdr xdr = ec.getXDR();
	
	switch( method )
	{
	case IDTranslatorSession.TYPE_NEW_FLOW:
	    {
		TypeID flowID;
		
		flowID = xdr.TYPEID();
		this.newFlow(ec.getReferences()[0], flowID);
	    }
	    break;
	default:
	    Strict.fail();
	    break;
	}
    }

    /**
     * Call back used to notify the user of a new flow identifier.
     *
     * @param neighbor The Neighbor that sent the unknown Capsule identifier.
     * @param flowID The flow identifier that the unknown Capsule identifier
     * was mapped to.
     */
    public abstract void newFlow(CapabilityReference neighbor, TypeID flowID);

    public String toString()
    {
	return "IDTranslatorPresentation["
	    + super.toString()
	    + "]";
    }
}
