/*
 * Leak.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import edu.utah.janos.nodeos.BufferHandle;

/**
 * The Leak class is used to leak package private methods to other system
 * packages.
 */
public final class Leak
{
    /**
     * Get the flow identifier out of a ProtocolSession.
     *
     * @param ps An initialized ProtocolSession object.
     * @return A byte array containing the flow identifier that the protocol
     * belongs to.
     */
    public static byte[] getFlowID(ProtocolSession ps)
    {
	return ps.getSessionType().getFlowType().getFlowID().getHash();
    }

    /**
     * @param ec An initialized ExternalCapsule.
     * @return The BufferHandle that holds the ExternalCapsule's payload.
     */
    public static BufferHandle getBuffer(ExternalCapsule ec)
    {
	return ec.getBuffer();
    }

    /**
     * Initialize an ExternalCapsule from the given arguments.
     *
     * @param ec The ExternalCapsule to initialize or null if one should be
     * created.
     * @param source The source of the ExternalCapsule.
     * @param ps The ProtocolSession the capsule should be bound to.
     * @param bh The BufferHandle containing the capsule's payload.
     * @return The "ec" argument or the newly created object.
     */
    public static ExternalCapsule toCapsule(ExternalCapsule ec,
					    ExternalChannel source,
					    ProtocolSession ps,
					    BufferHandle bh)
    {
	ExternalCapsule retval = ec;

	if( ec == null )
	    retval = new ExternalCapsule();
	retval.setSource(source);
	retval.setSessionType(ps.getSessionType());
	retval.getXDR().readReset(bh);
	return retval;
    }

    /**
     * Private constructor, this is a static-only class.
     */
    private Leak()
    {
    }
}
