/*
 * NamedCapabilitiesEvent.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import bees.core.bdomain.DeadBDomainException;

final class NamedCapabilitiesEvent
    extends TwoWayBeesEvent
{
    private CapabilityEnvelope ce[];
    
    NamedCapabilitiesEvent(InheritedCapabilityCoroutine icc,
			   CapabilityEnvelope ce[])
    {
	super(icc);
	
	this.ce = ce;
    }

    void setEnvelopes(CapabilityEnvelope ce[])
    {
	this.ce = ce;
    }

    CapabilityEnvelope[] getEnvelopes()
    {
	return this.ce;
    }

    protected void sendReply()
	throws DeadBDomainException
    {
	this.ce = null;
	
	super.sendReply();
    }

    public Object clone()
    {
	Object retval = super.clone();
	NamedCapabilitiesEvent nce;

	nce = (NamedCapabilitiesEvent)retval;
	if( this.ce != null )
	{
	    int lpc;
	    
	    nce.ce = new CapabilityEnvelope[this.ce.length];
	    for( lpc = 0; lpc < this.ce.length; lpc++ )
	    {
		if( this.ce[lpc] != null )
		    nce.ce[lpc] = (CapabilityEnvelope)this.ce[lpc].clone();
	    }
	}
	return retval;
    }
    
    public String toString()
    {
	return "NamedCapabilitiesEvent["
	    + super.toString()
	    + "; ce="
	    + this.ce
	    + "]";
    }
}
