/*
 * NodeAuthorization.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

final class NodeAuthorization
    extends AuthorizationCoroutine
{
    NodeAuthorization(StateResponder sr, AuthorizationCoroutine ac)
    {
	super(sr, ac);
    }

    NodeAuthorization(AuthorizationCoroutine ac)
    {
	super(ac);
    }

    NodeAuthorization()
    {
    }

    private Authorizer getAuthorizer()
    {
	Authorizer retval;
	Node node;
	
	node = Node.currentNode();
	retval = node.getAuthorizer();
	return retval;
    }

    protected void beginManagement(CapabilityEnvelope ce, TypeID sessionID)
    {
	Authorizer authorizer;
	
	if( (authorizer = this.getAuthorizer()) != null )
	{
	    authorizer.beginManagement(ce, sessionID);
	}
    }
    
    protected void beginExtendedManagement(CapabilityEnvelope ce,
					   TypeID sessionID)
    {
	Authorizer authorizer;
	
	if( (authorizer = this.getAuthorizer()) != null )
	{
	    authorizer.beginExtendedManagement(ce, sessionID);
	}
    }
    
    protected CapabilityEnvelope[] authorize(CapabilityEnvelope requester,
					     String src,
					     String dst,
					     byte auth[])
    {
	CapabilityEnvelope retval[] = null;
	Authorizer authorizer;
	
	if( (authorizer = this.getAuthorizer()) != null )
	{
	    retval = authorizer.authorize(requester, src, dst, auth).flatten();
	}
	return retval;
    }

    public String toString()
    {
	return "NodeAuthorization["
	    + super.toString()
	    + "]";
    }
}
