/*
 * NodeHandler.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import java.util.Vector;
import java.util.Enumeration;
import java.util.NoSuchElementException;

import edu.utah.janos.nodeos.AddressFormatException;

import edu.utah.janosvm.kit.comm.jsi.JSIPair;
import edu.utah.janosvm.kit.comm.jsi.JSIHandler;
import edu.utah.janosvm.kit.comm.jsi.JSIMessage;
import edu.utah.janosvm.kit.comm.jsi.JSIPropertyInfo;
import edu.utah.janosvm.kit.comm.jsi.JSIHandlerContext;
import edu.utah.janosvm.kit.comm.jsi.MissingPairException;

import bees.core.kernel.KernelObject;
import bees.core.kernel.KernelObjectStore;
import bees.core.kernel.KernelCapabilities;
import bees.core.kernel.KernelObjectCoroutine;

import bees.core.resource.CapabilityHandler;

import bees.core.security.PermissionSet;

import bees.core.bdomain.BDomain;

public final class NodeHandler
    extends CapabilityHandler
{
    public NodeHandler()
    {
    }

    public Class getCapabilityClass()
    {
	return Node.class;
    }

    public Object createCapability(JSIMessage jm,
				   String name,
				   String comment)
	throws AddressFormatException,
	       MissingPairException
    {
	String clock, nodeName, nodeVersion;
	CapabilityEnvelope ce;
	Object obj;
	
	nodeName = jm.get("nodeName", "Unknown");
	nodeVersion = jm.get("version", BeesVersion.NODE_VERSION);
	clock = jm.get("clock", "clock");
	obj = super.tree.get(clock);
	if( obj instanceof CapabilityEnvelope )
	{
	    ce = (CapabilityEnvelope)obj;
	}
	else
	{
	    ce = new CapabilityEnvelope((Capability)obj);
	}
	return KernelObjectCoroutine.
	    create(new Node(),
		   BDomain.currentBDomain().getBDomainCoroutine(),
		   NodeSpec.marshal(nodeName, nodeVersion),
		   new CapabilityEnvelope[] {
		       ce,
		   },
		   comment,
		   KernelCapabilities.toPermissionSet(jm));
    }
    
    public void getSuites(JSIMessage jm)
    {
    }
    
    public String toString()
    {
	return "NodeHandler["
	    + "]";
    }
}
