/*
 * ObjectMap.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import java.util.Enumeration;

/**
 * A simple mapping interface, used mainly for backwards compatability.
 */
public interface ObjectMap
{
    /**
     * Get an object mapping.
     *
     * @param key The key of the object to get out of the mapping.
     * @return The object matching the given key or null.
     */
    Object get(Object key);
    
    /**
     * Remove an object mapping.
     *
     * @param key The key of the object to remove from the mapping.
     * @return The object matching the given key or null.
     */
    Object remove(Object key);
    
    /**
     * @param key The key of the object to put in the mapping.
     * @param value The object value to map.
     * @return The previous object that was in this mapping.
     */
    Object put(Object key, Object value);

    /**
     * @return An enumeration containing the keys in the mapping.
     */
    Enumeration keys();

    /**
     * @return An enumeration containing the object values in the mapping.
     */
    Enumeration elements();

    int size();
}
