/*
 * SessionType.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import java.util.Vector;
import java.util.Hashtable;

import edu.utah.janos.nodeos.Domain;

import bees.util.MD5;

import bees.core.resource.Logger;

import bees.core.bdomain.BDomainLocal;

final class SessionType
{
    private static final BDomainLocal domainSessions = new BDomainLocal() {
	    protected Object initialValue()
	    {
		return new Hashtable();
	    }
	};

    private static final BDomainLocal domainFlows = new BDomainLocal() {
	    protected Object initialValue()
	    {
		return new Hashtable();
	    }
	};
    
    static Hashtable getBDomainSessions()
    {
	return (Hashtable)domainSessions.get();
    }

    static Hashtable getBDomainFlows()
    {
	return (Hashtable)domainFlows.get();
    }

    static void putBDomainSession(SessionType st)
    {
	Hashtable ht = (Hashtable)domainSessions.get();

	synchronized( ht )
	{
	    if( !ht.containsKey(st.sessionID) )
	    {
		Hashtable sub;
		
		ht.put(st.sessionID, st);
		ht = (Hashtable)domainFlows.get();
		if( (sub = (Hashtable)ht.get(st.ft.getFlowID())) == null )
		{
		    sub = new Hashtable();
		    ht.put(st.ft.getFlowID(), sub);
		}
		sub.put(st.pt.getProtocolID(), st);
	    }
	}
    }

    static SessionType getBDomainSession(TypeID sessionID)
    {
	Hashtable ht = (Hashtable)domainSessions.get();
	
	return (SessionType)ht.get(sessionID);
    }

    static SessionType getBDomainSession(TypeID flowID, TypeID protocolID)
    {
	Hashtable ht = (Hashtable)domainFlows.get();
	SessionType retval = null;

	synchronized( domainSessions.get() )
	{
	    if( (ht = (Hashtable)ht.get(flowID)) != null )
		retval = (SessionType)ht.get(protocolID);
	}
	return retval;
    }

    private FlowType ft;
    private ProtocolType pt;
    private TypeID sessionID;

    private Hashtable locals = new Hashtable();

    private ProtocolSession session;
    
    SessionType()
    {
    }

    SessionType setFlowType(FlowType ft)
    {
	this.ft = ft;
	return this;
    }

    FlowType getFlowType()
    {
	return this.ft;
    }

    SessionType setProtocolType(ProtocolType pt)
    {
	this.pt = pt;
	return this;
    }

    ProtocolType getProtocolType()
    {
	return this.pt;
    }

    SessionType setSessionID(TypeID sessionID)
    {
	this.sessionID = sessionID;
	return this;
    }

    TypeID getSessionID()
    {
	return this.sessionID;
    }

    Hashtable getLocals()
    {
	return this.locals;
    }

    synchronized ProtocolSession getSession()
	throws ClassNotFoundException,
	       InstantiationException,
	       IllegalAccessException
    {
	ProtocolSession retval;
	
	if( this.session == null )
	{
	    Domain domain = Domain.currentDomain();
	    Node node;
	    Class cl;

	    node = Node.currentNode();
	    cl = domain.loadClass(this.pt.getSessionClassName());
	    this.session = (ProtocolSession)cl.newInstance();
	    this.session.setSessionType(this);
	}
	retval = this.session;
	return retval;
    }

    SessionType snapshotSessionType()
    {
	MD5 digest = new MD5();

	digest.update(this.ft.getFlowID().getHash());
	digest.update(this.pt.getProtocolID().getHash());
	this.sessionID = new TypeID(digest.hash());
	return this;
    }

    public String toString()
    {
	return "SessionType[ft="
	    + this.ft
	    + "; pt="
	    + this.pt
	    + "; sessionID="
	    + this.sessionID
	    + "]";
    }
}
