/*
 * UnknownProtocolSession.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import java.io.IOException;

import java.util.Vector;
import java.util.Enumeration;

import bees.core.resource.Logger;

import bees.core.bdomain.BDomain;
import bees.core.bdomain.BDomainLocal;

final class UnknownProtocolSession
    extends ExtendedProtocolSession
{
    static final int TYPE_NEW_PROTOCOL = METHOD_USER + 1;
    static final int TYPE_REQUEST_DESC = METHOD_USER + 2;

    UnknownProtocolSession()
    {
    }

    public void userReceive(Node node, int method, ExternalCapsule ec)
    {
	Xdr xdr = ec.getXDR();
	
	switch( method )
	{
	case TYPE_REQUEST_DESC:
	    {
		CapabilityReference cr;
		TypeID flowID;
		NodeCache nc;

		nc = super.getCache();
		cr = ec.getReferences()[0];
		flowID = xdr.TYPEID();
		synchronized( nc )
		{
		    if( nc.get(flowID) != null )
		    {
			/* We're already trying to do the download. */
			flowID = null;
		    }
		}
		if( (flowID != null) &&
		    !UnknownProtocol.containsFlowDesc(flowID) )
		{
		    try
		    {
			FlowRequestCapsule frc;
			Neighbor neighbor;
			NeighborImpl ni;
			
			ni = (NeighborImpl)cr.dereference();
			neighbor = ni.getNeighbor(ec);
			frc = new FlowRequestCapsule(neighbor, flowID);
			frc.fromExternal(ec, flowID);
			super.getCache().put(flowID,
					     frc,
					     ReliableDataRequestCapsule.
					     DEFAULT_RETRY_INTERVAL);
			neighbor.send(frc);
		    }
		    catch(MissingCapabilityException e)
		    {
			Logger.log(e);
		    }
		    catch(EncodingException e)
		    {
			Logger.log(e);
		    }
		    catch(IOException e)
		    {
			Logger.log(e);
		    }
		}
	    }
	    break;
	default:
	    Strict.fail();
	    break;
	}
    }

    public String toString()
    {
	return "UnknownProtocolSession["
	    + super.toString()
	    + "]";
    }
}
