/*
 * WorkerList.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

final class WorkerList
{
    private final Object queue[];
    private boolean alive = true;
    private int queueStart;
    private int queueEnd;
    
    WorkerList(int maxQueueSize)
    {
	Assert.require(maxQueueSize > 0);
	
	this.queue = new Object[maxQueueSize];
    }

    synchronized void kill()
    {
	this.alive = false;
	this.notifyAll();
    }

    synchronized void addWork(Object obj)
    {
	this.queue[this.queueEnd] = obj;
	this.queueEnd = (this.queueEnd + 1) % this.queue.length;
	this.notify();
    }

    synchronized Object getWork()
	throws InterruptedException
    {
	Object retval = null;

	while( this.alive && (retval == null) )
	{
	    if( this.queue[this.queueStart] == null )
	    {
		this.wait();
	    }
	    else
	    {
		retval = this.queue[this.queueStart];
		this.queue[this.queueStart] = null;
		this.queueStart = (this.queueStart + 1) % this.queue.length;
	    }
	}
	return retval;
    }
    
    public String toString()
    {
	return "WorkerList[queue="
	    + this.queue
	    + "; alive="
	    + this.alive
	    + "; queueStart="
	    + this.queueStart
	    + "; queueEnd="
	    + this.queueEnd
	    + "]";
    }
}
