/*
 * DischargeBDomainCoroutine.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.bdomain;

import bees.core.Panic;
import bees.core.Assert;
import bees.core.Strict;
import bees.core.BeesEvent;
import bees.core.EventChannel;
import bees.core.StateResponder;
import bees.core.ResponderCoroutine;

public final class DischargeBDomainCoroutine
    extends ResponderCoroutine
{
    public static final int STATE_WAITING = STATE_USER;

    public DischargeBDomainCoroutine(StateResponder sr)
    {
	super(sr);
    }
    
    public DischargeBDomainCoroutine()
    {
	this(null);
    }

    public void discharge(EventChannel ec)
    {
	try
	{
	    DischargeBDomainEvent dse;

	    Assert.require(ec);
	    
	    dse = new DischargeBDomainEvent(this);
	    dse.useBDomainReplyPort();
	    ec.sendEvent(dse);
	    this.setState(STATE_WAITING);
	}
	catch(DeadBDomainException e)
	{
	    this.setState(STATE_ERROR_CAGED);
	}
	catch(Throwable th)
	{
	    super.setThrowable(th);
	}
    }

    public void handle(BeesEvent ae)
    {
	switch( super.getState() )
	{
	case STATE_NEWBORN:
	    if( (ae instanceof DischargeBDomainEvent) && !ae.isReply() )
	    {
		DischargeBDomainEvent dse;
		
		dse = (DischargeBDomainEvent)ae;
		try
		{
		    BDomain bdomain;
		    
		    bdomain = BDomain.currentBDomain();
		    bdomain.cleanup();
		}
		catch(Throwable th)
		{
		    dse.setThrowable(th);
		}
		this.setState(STATE_COMPLETE);
		try
		{
		    dse.sendReply();
		}
		catch(DeadBDomainException e)
		{
		}
	    }
	    else
	    {
		Strict.fail();
	    }
	    break;
	case STATE_WAITING:
	    if( (ae instanceof DischargeBDomainEvent) && ae.isReply() )
	    {
		DischargeBDomainEvent dse;
		Throwable th;

		dse = (DischargeBDomainEvent)ae;
		if( (th = dse.getThrowable()) != null )
		{
		    super.setThrowable(th);
		}
		else
		{
		    this.setState(STATE_COMPLETE);
		}
	    }
	    else
	    {
		Strict.fail();
	    }
	    break;
	default:
	    throw new Panic("Invalid state for coroutine: " + this);
	}
    }
    
    public String toString()
    {
	return "DischargeBDomainCoroutine["
	    + super.toString()
	    + "]";
    }
}
