/*
 * BDomainEndingEvent.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.kernel;

import edu.utah.janosvm.kit.comm.amiga.FaxPortHandle;

import bees.core.Assert;
import bees.core.BeesEvent;
import bees.core.Coroutine;

import bees.core.bdomain.DeadBDomainException;

public final class BDomainEndingEvent
    extends BeesEvent
{
    private BDomainIdentifier ai;
    
    BDomainEndingEvent(Coroutine c, BDomainIdentifier ai)
    {
	super(c);

	this.ai = ai;
    }

    BDomainEndingEvent(Coroutine c)
    {
	this(c, null);
    }
    
    BDomainIdentifier getIdentifier()
    {
	return this.ai;
    }

    public Object clone()
    {
	BDomainEndingEvent aee;

	aee = (BDomainEndingEvent)super.clone();
	if( aee.ai != null )
	{
	    aee.ai = (BDomainIdentifier)this.ai.clone();
	}
	return aee;
    }

    public String toString()
    {
	return "BDomainEndingEvent["
	    + super.toString()
	    + "; ai="
	    + this.ai
	    + "]";
    }
}
