/*
 * BDomainQueryEvent.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.kernel;

import edu.utah.janos.nodeos.ChanStats;
import edu.utah.janos.nodeos.DomainStats;
import edu.utah.janos.nodeos.ThreadStats;

import bees.core.Assert;
import bees.core.Coroutine;
import bees.core.TwoWayBeesEvent;

import bees.core.bdomain.DeadBDomainException;

public final class BDomainQueryEvent
    extends TwoWayBeesEvent
{
    private BDomainIdentifier ai;
    private DomainStats ds;
    private ThreadStats ts[];
    private ChanStats ics[];
    private ChanStats ocs[];
    
    BDomainQueryEvent(Coroutine src, BDomainIdentifier ai)
    {
	super(src);

	this.ai = ai;
    }

    BDomainQueryEvent(Coroutine src)
    {
	this(src, null);
    }

    BDomainIdentifier getIdentifier()
    {
	return this.ai;
    }

    void setDomainStats(DomainStats ds)
    {
	this.ds = ds;
    }

    public DomainStats getDomainStats()
    {
	return this.ds;
    }

    void setThreadStats(ThreadStats ts[])
    {
	this.ts = ts;
    }

    ThreadStats[] getThreadStats()
    {
	return this.ts;
    }

    void setInChanStats(ChanStats cs[])
    {
	this.ics = cs;
    }

    public ChanStats[] getInChanStats()
    {
	return this.ics;
    }

    void setOutChanStats(ChanStats cs[])
    {
	this.ocs = cs;
    }

    public ChanStats[] getOutChanStats()
    {
	return this.ocs;
    }

    protected void sendReply()
	throws DeadBDomainException
    {
	super.sendReply();
    }

    public Object clone()
    {
	Object retval = super.clone();
	BDomainQueryEvent aqe;

	aqe = (BDomainQueryEvent)retval;
	if( aqe.ai != null )
	{
	    aqe.ai = (BDomainIdentifier)this.ai.clone();
	}
	if( aqe.ds != null )
	{
	    aqe.ds = (DomainStats)this.ds.clone();
	}
	if( aqe.ics != null )
	{
	    int lpc;
	    
	    aqe.ics = (ChanStats[])this.ics.clone();
	    for( lpc = 0; lpc < aqe.ics.length; lpc++ )
	    {
		aqe.ics[lpc] = (ChanStats)this.ics[lpc].clone();
	    }
	}
	if( aqe.ocs != null )
	{
	    int lpc;
	    
	    aqe.ocs = (ChanStats[])this.ocs.clone();
	    for( lpc = 0; lpc < aqe.ocs.length; lpc++ )
	    {
		aqe.ocs[lpc] = (ChanStats)this.ocs[lpc].clone();
	    }
	}
	return retval;
    }

    public String toString()
    {
	return "BDomainQueryEvent["
	    + super.toString()
	    + "; ai="
	    + this.ai
	    + "; ds="
	    + this.ds
	    + "; ts="
	    + this.ts
	    + "; ics="
	    + this.ics
	    + "; ocs="
	    + this.ocs
	    + "]";
    }
}
