/*
 * ConnectBDomainEvent.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.kernel;

import edu.utah.janosvm.kit.comm.amiga.FaxPortHandle;

import bees.core.Assert;
import bees.core.ByteArray;
import bees.core.TwoWayBeesEvent;

import bees.core.bdomain.DeadBDomainException;

/**
 * The event used by ConnectBDomainCoroutine to carry an data.
 */
final class ConnectBDomainEvent
    extends TwoWayBeesEvent
{
    /**
     * The domain identifier.
     */
    private byte id[];
    
    /**
     * The domain's fax port.
     */
    private FaxPortHandle port;

    /**
     * Contruct a ConnectBDomainEvent with the given values.
     *
     * @param csc The coroutine that is using the event.
     * @param id The domain identifier.
     */
    ConnectBDomainEvent(ConnectBDomainCoroutine csc, byte id[])
    {
	super(csc);

	Assert.require(id);
	
	this.id = id;
    }

    /**
     * @param id The domain identifier.
     */
    void setID(byte id[])
    {
        this.id = id;
    }
    
    /**
     * @return The domain identifier.
     */
    byte[] getID()
    {
	return this.id;
    }

    /**
     * @param port The domain's fax port.
     */
    void setPort(FaxPortHandle port)
    {
	this.port = port;
    }

    /**
     * @return The domain's fax port.
     */
    FaxPortHandle getPort()
    {
	return this.port;
    }

    protected void sendReply()
	throws DeadBDomainException
    {
	this.id = null;
	
	super.sendReply();
    }
    
    public Object clone()
    {
	Object retval = super.clone();
	ConnectBDomainEvent cse;

	cse = (ConnectBDomainEvent)retval;
	if( this.id != null )
	    cse.id = (byte[])this.id.clone();
	if( this.port != null )
	    cse.port = this.port.cloneHandle();
	return retval;
    }

    public String toString()
    {
	return "ConnectBDomainEvent["
	    + super.toString()
	    + "; id="
	    + ByteArray.toString(this.id)
	    + "; port="
	    + this.port
	    + "]";
    }
}
