/*
 * ListBDomainEvent.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.kernel;

import bees.core.Assert;
import bees.core.TwoWayBeesEvent;

import bees.core.bdomain.DeadBDomainException;

/**
 * Event used by the ListBDomainCoroutine.
 */
final class ListBDomainEvent
    extends TwoWayBeesEvent
{
    /**
     * An array of the domain's KernelObject identifiers.
     */
    private long id[];
    
    /**
     * An array of the domain's identifiers.
     */
    private BDomainIdentifier si[];

    /**
     * @param lsc The coroutine using this event.
     */
    public ListBDomainEvent(ListBDomainCoroutine lsc)
    {
	super(lsc);
    }

    /**
     * @param id An array of the domain's KernelObject identifiers.
     */
    void setStoreIDs(long id[])
    {
	this.id = id;
    }
    
    /**
     * @return An array of the domain's KernelObject identifiers.
     */
    long[] getStoreIDs()
    {
	return this.id;
    }

    /**
     * @param si An array of the domain's identifiers.
     */
    void setBDomainIdentifiers(BDomainIdentifier si[])
    {
	this.si = si;
    }

    /**
     * @return An array of the domain's identifiers.
     */
    BDomainIdentifier[] getBDomainIdentifiers()
    {
	return this.si;
    }

    protected void sendReply()
	throws DeadBDomainException
    {
	Assert.require(this.id);
	Assert.require(this.si);
	
	super.sendReply();
    }

    public Object clone()
    {
	Object retval = super.clone();
	ListBDomainEvent lse;
	
	lse = (ListBDomainEvent)retval;
	if( this.id != null )
	    lse.id = (long[])this.id.clone();
	if( this.si != null )
	{
	    int lpc;

	    lse.si = new BDomainIdentifier[this.si.length];
	    for( lpc = 0; lpc < this.si.length; lpc++ )
	    {
		lse.si[lpc] = (BDomainIdentifier)this.si[lpc].clone();
	    }
	}
	return retval;
    }

    public String toString()
    {
	return "ListBDomainEvent["
	    + super.toString()
	    + "; id="
	    + this.id
	    + "; si="
	    + this.si
	    + "]";
    }
}
