/*
 * LoggerTest.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.tests;

import bees.core.Node;
import bees.core.ObjectTree;

import bees.core.resource.File;
import bees.core.resource.Logger;
import bees.core.resource.Console;
import bees.core.resource.Directory;
import bees.core.resource.LoggerSpec;
import bees.core.resource.LoggerFactory;
import bees.core.resource.FileSystemRoot;

import bees.core.security.Permission;
import bees.core.security.PermissionSet;
import bees.core.security.FilePermission;
import bees.core.security.PermissionException;

public final class LoggerTest
    implements Test
{
    public void test(Node node)
	throws Throwable
    {
	final LoggerFactory lf = new LoggerFactory();
	FileSystemRoot cwd;
	Console console;
	Directory dir;
	Logger log;
	File file;
	
	Logger.log("Hello, World!");

	console = (Console)node.getCapability("console");
	log = lf.create(console, new LoggerSpec("My Log", 0));
	log.start();
	log.logMessage("Hello, World!");

	cwd = (FileSystemRoot)node.getCapability("cwd");
	dir = cwd.root();
	dir.delete("LoggerTest.extra");
	
	file = dir.file("LoggerTest.extra",
			new PermissionSet(new Permission[] {
			    new FilePermission("file", "append"),
			}),
			true);
	log = lf.create(file, new LoggerSpec("File Log", 0));
	log.start();
	log.logMessage("Hello, World!");
	try { log.logMessage(-1, "Bad level #1"); }
	catch(IllegalArgumentException e)
	{
	    Logger.log(e.toString());
	}
	try { log.logMessage(100, "Bad level #2"); }
	catch(IllegalArgumentException e)
	{
	    Logger.log(e.toString());
	}
	try { log.logThrowable(-1, new Throwable()); }
	catch(IllegalArgumentException e)
	{
	    Logger.log(e.toString());
	}
	try { log.logThrowable(100, new Throwable()); }
	catch(IllegalArgumentException e)
	{
	    Logger.log(e.toString());
	}
    }
}
