/*
 * NodeTest.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.tests;

import bees.core.Node;
import bees.core.NodeSpec;
import bees.core.NodeCache;
import bees.core.ObjectTree;
import bees.core.NodeFactory;
import bees.core.ProtocolSession;
import bees.core.CapabilityEnvelope;

import bees.core.resource.File;
import bees.core.resource.Clock;
import bees.core.resource.Logger;
import bees.core.resource.Console;
import bees.core.resource.Directory;
import bees.core.resource.LoggerSpec;
import bees.core.resource.LoggerFactory;
import bees.core.resource.FileSystemRoot;

import bees.core.security.Permission;
import bees.core.security.PermissionSet;
import bees.core.security.FilePermission;
import bees.core.security.IntegerPermission;
import bees.core.security.PermissionException;

public final class NodeTest
    implements Test, NodeCache.EventHandler
{
    private static final IntegerPermission INTERVAL =
	new IntegerPermission("interval", 10);
    
    private long start, end;
    private int count = 5;
    private Clock clock;
    
    public void test(Node node)
	throws Throwable
    {
	NodeCache nc;

	this.clock = (Clock)node.getCapability("clock");
	nc = new NodeCache(node, 15);
	nc.put(this, this, INTERVAL);
	synchronized( this )
	{
	    while( this.end == 0 )
	    {
		this.wait();
	    }
	}
	if( (end - start) >= 1500 )
	{
	    Logger.log("Success");
	}
	else
	{
	    Logger.log("Short time: " + (end - start));
	}
    }

    public void removed(Node node, ProtocolSession ps)
    {
    }

    public IntegerPermission collected(Node node, ProtocolSession ps)
    {
	IntegerPermission retval = null;
	
	if( this.start == 0 )
	{
	    this.start = this.clock.current();
	}
	else
	{
	    this.end = this.clock.current();
	}
	this.count -= 1;
	if( this.count > 0 )
	{
	    retval = INTERVAL;
	}
	else
	{
	    synchronized( this )
	    {
		this.notifyAll();
	    }
	}
	return retval;
    }
}
