/*
 * OutOfCapabilityMemory.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.tests;

import java.util.Vector;

import bees.core.Node;

import bees.core.resource.Logger;

import bees.core.security.SecretKey;
import bees.core.security.KeyGenerator;
import bees.core.security.PermissionException;

public final class OutOfCapabilityMemory
    implements Test
{
    private Vector allocateKeys()
	throws Throwable
    {
	final Vector retval = new Vector();
	
	try
	{
	    KeyGenerator kg;

	    kg = new KeyGenerator();
	    for( ; ; )
	    {
		retval.addElement(kg.generateKey("DES", 0));
	    }
	}
	catch(PermissionException e)
	{
	    Logger.log(e.toString());
	}
	return retval;
    }
    
    public void test(Node node)
	throws Throwable
    {
	final Vector keys;
	int size;
	
	keys = this.allocateKeys();
	size = keys.size();
	try
	{
	    while( true )
	    {
		SecretKey sk;
		
		sk = (SecretKey)keys.elementAt(0);
		keys.removeElementAt(0);
		sk.deleteCapability();
	    }
	}
	catch(ArrayIndexOutOfBoundsException e)
	{
	    /* Ignore. */
	}
	if( this.allocateKeys().size() == size )
	{
	    Logger.log("Able to delete and reallocate capability memory.");
	}
	else
	{
	    Logger.log("Delete failed?");
	}
    }
}
