/*
 * BenchmarkBootCapsule.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package apps.benchmark;

import java.util.Properties;
import java.util.NoSuchElementException;

import java.io.IOException;
import java.io.ByteArrayInputStream;

import bees.core.Xdr;
import bees.core.Node;
import bees.core.Capsule;
import bees.core.Neighbor;
import bees.core.NodeCache;
import bees.core.NeighborImpl;
import bees.core.ProtocolSession;
import bees.core.DLProtocolSession;
import bees.core.EncodingException;

import bees.core.resource.Clock;
import bees.core.resource.Logger;

public final class BenchmarkBootCapsule
    extends Capsule
{
    public BenchmarkBootCapsule()
    {
    }

    public void encode(Xdr xdr)
    {
    }

    public void decode(Xdr xdr)
    {
    }

    public void evaluate(Node node)
	throws ClassNotFoundException,
	       EncodingException,
	       IOException
    {
	BenchmarkParameters bp;
	DLProtocolSession dps;
	BenchmarkSession bs;
	
	Logger.log(Logger.INFO,
		   "Benchmark Protocol v"
		   + BenchmarkSession.VERSION_MAJOR
		   + "."
		   + BenchmarkSession.VERSION_MINOR);
	bs = (BenchmarkSession)this.getSession();
	bp = new BenchmarkParameters(bs);
	bp.initialize(node, bs);
	bs.bp = bp;

	dps = (DLProtocolSession)
	    this.getSession("bees.core.DLProtocolSession");
	if( dps.getPreviousNeighbor() == null )
	{
	    PrimerCapsule pc;
	    
	    pc = new PrimerCapsule();
	    pc.fromCapsule(this);
	    bs.getCache().put("primer", pc, PrimerCapsule.PRIME_FREQUENCY);
	    node.setJSIHandler("send", bs);
	    node.setJSIHandler("relay", bs);
	}
	node.beginManagement(bs);
    }

    public String toString()
    {
	return "BenchmarkBootCapsule["
	    + super.toString()
	    + "]";
    }
}
