/*
 * BenchmarkCapsule.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package apps.benchmark;

import bees.core.Xdr;
import bees.core.Node;
import bees.core.Capsule;
import bees.core.ProtocolSession;

import bees.core.resource.Clock;
import bees.core.resource.Logger;

public class BenchmarkCapsule
    extends Capsule
{
    private static final int MAX_DATA_SIZE = 2048;
    
    private int dataLength;
    private final byte data[] = new byte[MAX_DATA_SIZE];
    
    public BenchmarkCapsule()
    {
    }

    public void setDataLength(int length)
    {
	this.dataLength = length;
    }
    
    public void encode(Xdr xdr)
    {
	xdr.PUT(this.data, 0, this.dataLength);
    }

    public void decode(Xdr xdr)
    {
	this.dataLength = xdr.getUnreadLength();
	xdr.BYTES(this.data, 0, this.dataLength);
    }
    
    public void recordHit(Node node, BenchmarkSession bs)
    {
	long current = 0, diff = 0;
	
	bs.currentRun.packetCount += 1;
	bs.intervalCount += 1;
	current = bs.bp.clock.current();
	if( bs.currentRun.last == 0 )
	{
	    bs.currentRun.start = current;
	    bs.lastStat = current;
	}
	bs.currentRun.last = current;
	diff = current - bs.lastStat;
	if( diff >= bs.bp.statInterval )
	{
	    long total, secs, usecs;
	    
	    total = current - bs.currentRun.start;
	    secs = total / 1000;
	    usecs = (total % 1000) * 10;
	    Logger.log("\nPacket length: "
		       + this.dataLength
		       + "\ncycle "
		       + bs.currentRun.packetCount
		       + ":\n  secs: "
		       + secs
		       + "\n  interval-pps: "
		       + (bs.intervalCount / (bs.bp.statInterval / 1000))
		       + "\n  continuous-pps: "
		       + (bs.currentRun.packetCount / secs));
	    bs.lastStat = current;
	    bs.intervalCount = 0;
	}
    }

    public String toString()
    {
	return "BenchmarkCapsule["
	    + super.toString()
	    + "; dataLength="
	    + this.dataLength
	    + "]";
    }
}
