#
# monitor.py
#
# Copyright (c) 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Bees Software.
#
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#

# Webmin monitor for the Health protocol

import time
import health

from jsi.messageError import *

# Create an object that can communicate with the Health JSI handler.
server = health.Health(channel, capability)

retryCount = 5
clients = None

# Retry until the handler is attached or we bail
while retryCount > 0:
    try:
        clients = server.listClients()
        clients.sort()
        retryCount = 0
    except MessageError:
        time.sleep(0.25)
        retryCount -= 1
    except IOError:
        time.sleep(0.25)
        retryCount -= 1

# State value to image map
state_map = {
    "fine" : "/images/greenball.gif",
    "on-fire" : "/images/redball.gif",
    }

# Template of the main table
body_template = """
<tr><td colspan=5>
<table cellspacing=2 border=1>
<tr><td>Node Name</td><td>State</td></tr>
%(client-rows)s
</table>
</td></tr>
<tr>
<td><input type="submit" name="monitor_submit" value="Terminate"></td>
</tr>
"""

# Template for each client entry
client_template = """
<tr>
<td>%(name)s</td>
<td><center><img src="%(state-img)s" alt="%(state)s"></center></td>
</tr>
"""

health_config = {
    "client-rows" : ""
    }

if form.has_key("monitor_submit"):
    if form["monitor_submit"].value == "Terminate":
        server.shutdown()
if clients != None:
    if len(clients) == 0:
        health_config["client-rows"] = (
            "<tr><td colspan=2>No clients yet</td></tr>")
    # Get the State for each client.
    for client in clients:
        state = server.getClientHealth(client)
        client_config = {
            "name" : client,
            "state" : state,
            "state-img" : state_map[state],
            }
        health_config["client-rows"] = (health_config["client-rows"]
                                        + client_template % client_config)    
    config["protocol-specific-args"] = body_template % health_config
else:
    config["protocol-specific-args"] = "Unable to contact Health protocol"
