/*
 * LiveNeighbor.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package apps.liveness;

import bees.core.Node;
import bees.core.Neighbor;
import bees.core.NodeCache;
import bees.core.NeighborImpl;
import bees.core.ProtocolSession;

import bees.core.security.IntegerPermission;

/**
 * A LiveNeighbor is a Neighbor subclass that is used to track the
 * responsiveness of a neighbor.
 */
public final class LiveNeighbor
    extends Neighbor
    implements NodeCache.EventHandler
{
    /**
     * Indicated whether or not a PokeCapsule was received from this neighbor
     * during the last time period.
     */
    private boolean touched = false;

    /**
     * Construct a LiveNeighbor with the given values.
     *
     * @param ni The NeighborImpl to wrap and activate.
     */
    public LiveNeighbor(NeighborImpl ni)
    {
	super(ni);
    }

    /**
     * Touch this neighbor.
     */
    void touch()
    {
	this.touched = true;
    }

    /**
     * @see bees.core.NodeCache.EventHandler#removed(Node, ProtocolSession)
     */
    public void removed(Node node, ProtocolSession ps)
    {
    }

    /**
     * @see bees.core.NodeCache.EventHandler#collected(Node, ProtocolSession)
     */
    public IntegerPermission collected(Node node, ProtocolSession ps)
    {
	IntegerPermission retval = null;
	LivenessSession ls;

	ls = (LivenessSession)ps;
	if( this.touched )
	{
	    /* Poke response was received, renew our lease on life. */
	    this.touched = false;
	    retval = ls.getLivenessParameters().getExpirationTime();
	}
	else
	{
	    /* No response to pokes, tell the applications. */
	    ls.lostNeighbor(this.getNeighborImpl());
	}
	return retval;
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
	return "LiveNeighbor["
	    + super.toString()
	    + "; touched="
	    + this.touched
	    + "]";
    }
}
