/*
 * LivenessBootCapsule.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package apps.liveness;

import java.io.IOException;

import bees.core.Xdr;
import bees.core.Node;
import bees.core.Capsule;
import bees.core.EncodingException;

import bees.core.resource.Logger;

/**
 * A LivenessBootCapsule is used to boot strap the liveness protocol domain.
 */
public final class LivenessBootCapsule
    extends Capsule
{
    /**
     * Construct an empty LivenessBootCapsule.
     */
    public LivenessBootCapsule()
    {
    }

    /**
     * @see bees.core.Capsule#decode(Xdr)
     */
    public void decode(Xdr xdr)
    {
    }

    /**
     * @see bees.core.Capsule#encode(Xdr)
     */
    public void encode(Xdr xdr)
    {
    }
    
    /**
     * @see bees.core.Capsule#evaluate(Node)
     */
    public void evaluate(Node node)
	throws IOException,
	       EncodingException
    {
	LivenessParameters lp;
	LivenessSession ls;
	PokeCapsule pc;

	/* Say hi. */
	Logger.log(Logger.INFO,
		   "Liveness Protocol v"
		   + LivenessSession.VERSION_MAJOR
		   + "."
		   + LivenessSession.VERSION_MINOR);

	ls = (LivenessSession)this.getSession();
	/* Grab the parameters for this protocol flow. */
	lp = new LivenessParameters(ls);
	lp.initialize(node);
	ls.setLivenessParameters(lp);
	/* Create the main PokeCapsule. */
	pc = new PokeCapsule();
	pc.fromCapsule(this);
	ls.getCache().put(pc,
			  pc,
			  ls.getLivenessParameters().getPokeFrequency());
	/* Send an initial poke. */
	ls.getNeighborhood().send(pc);
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
	return "LivenessBootCapsule["
	    + super.toString()
	    + "]";
    }
}
