/*
 * Application.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

/**
 * Base class for Bees applications.  A Bees application executes in the same
 * JVM as the locally installed or downloaded protocols and is able to directly
 * interact with them.  Of course, the major difference between an application
 * and a protocol is that the application cannot be downloaded to other nodes.
 *
 * Currently, applications execute in a far less restricted environment than
 * protocols.  For example, there are no limitations on the classes they can
 * access and they are not forced to prepend an identifier onto any
 * cryptographic signatures they generate.
 *
 * @see bees.core.security.Signature
 * @see bees.core.resource.SystemClass
 */
public abstract class Application
{
    /**
     * Method called to set the application in motion.
     *
     * @param node The node object for this nodeos domain.
     * @param args The arguments to the application.
     * @throws Throwable If anything goes wrong.
     */
    public abstract void start(Node node, String args[])
	throws Throwable;

    /**
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
	return "Application["
	    + "]";
    }
}
