/*
 * CapsuleGroup.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import java.util.Vector;

/**
 * A CapsuleGroup is used to group together a set of related Capsules.
 */
public final class CapsuleGroup
{
    private final Vector group = new Vector();

    public CapsuleGroup()
    {
    }

    Vector getCapsules()
    {
	return this.group;
    }

    public synchronized void fromCapsule(Capsule cap)
    {
	int lpc, size;
	Neighbor src;

	cap.getPacketAuthorization().consume(PacketAuthorization.VALUE_GROUPS);
	
	src = cap.getSource();
	size = this.group.size();
	for( lpc = 0; lpc < size; lpc++ )
	{
	    /* XXX ... don't use fromNeigbhor... */
	    ((Capsule)this.group.elementAt(lpc)).fromNeighbor(src);
	}
    }

    public synchronized void add(Capsule cap)
    {
	if( !this.group.contains(cap) )
	{
	    cap.getCapsuleType().decGlobal(CapsuleType.GLOBAL_GROUPED);
	    this.group.addElement(cap);
	}
    }

    public synchronized void remove(Capsule cap)
    {
	if( this.group.removeElement(cap) )
	{
	    cap.getCapsuleType().incGlobal(CapsuleType.GLOBAL_GROUPED);
	}
    }

    public String toString()
    {
	return "CapsuleGroup[group="
	    + this.group
	    + "]";
    }
}
