/*
 * DisconnectSessionEvent.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import bees.core.bdomain.DeadBDomainException;

/**
 * Event used to disconnect two ExternalCoroutines.
 */
final class DisconnectSessionEvent
    extends TwoWayBeesEvent
{
    /**
     * Construct a DisconnectSessionEvent for the given coroutine.
     *
     * @param ec The source coroutine that wishes to disconnect.
     */
    DisconnectSessionEvent(ExternalCoroutine ec)
    {
	super(ec);
    }

    /**
     * @see bees.core.BeesEvent#sendReply()
     */
    protected void sendReply()
	throws DeadBDomainException
    {
	super.sendReply();
    }

    /**
     * @see java.lang.Object#clone()
     */
    public Object clone()
    {
	Object retval = super.clone();
	DisconnectSessionEvent cse;

	cse = (DisconnectSessionEvent)retval;
	return retval;
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
	return "DisconnectSessionEvent["
	    + super.toString()
	    + "]";
    }
}
