/*
 * IDTranslatorSession.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import java.io.IOException;

import java.util.Vector;
import java.util.Enumeration;

import bees.core.resource.Logger;

import bees.core.bdomain.BDomain;
import bees.core.bdomain.BDomainLocal;

/**
 * An IDTranslatorSession manages any IDTranslationProtocol state and interacts
 * with an external interests.
 */
public final class IDTranslatorSession
    extends ExtendedProtocolSession
{
    /**
     * New flow method type.
     */
    static final int TYPE_NEW_FLOW = METHOD_USER + 1;

    /**
     * Construct an empty IDTranslatorSession.
     */
    IDTranslatorSession()
    {
    }

    /**
     * @see bees.core.ProtocolSession#attachNeighbor(Node, Neighbor)
     */
    public void attachNeighbor(Node node, Neighbor neighbor)
    {
	neighbor = new UnknownNeighbor(neighbor.getNeighborImpl());
	super.attachNeighbor(node, neighbor);
    }

    /**
     * @see bees.core.ExtendedProtocolSession#addNeighbor(Node, ExternalCapsule, NeighborImpl)
     */
    public void addNeighbor(Node node, ExternalCapsule ec, NeighborImpl ni)
    {
	super.addNeighbor(node, ec, ni);
	Logger.log(Logger.INFO, "Adding neighbor: " + ni.getFingerPrint());
	if( ec != null )
	{
	    IDTranslatorCapsule itc;
	    UnknownNeighbor un;
		    
	    itc = new IDTranslatorCapsule();
	    itc.fromExternal(ec);
	    Logger.log(Logger.INFO,
		       "Attaching receivers for unknown capsules");
	    try
	    {
		if( (un = (UnknownNeighbor)ni.getNeighbor(this)) != null )
		{
		    un.attachUnknownReceiver(itc);
		}
	    }
	    catch(IOException e)
	    {
		Logger.log(e);
	    }
	}
    }

    public String toString()
    {
	return "IDTranslatorSession["
	    + super.toString()
	    + "]";
    }
}
