/*
 * NodeFactory.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import bees.core.kernel.KernelObjectCoroutine;

import bees.core.resource.Clock;

import bees.core.security.PermissionSet;

import bees.core.bdomain.BDomain;

/*
 * A factory for node objects.
 */
public final class NodeFactory
{
    private final BDomain bdomain;
    
    public NodeFactory()
    {
	this.bdomain = BDomain.currentBDomain();
    }

    public synchronized Node create(NodeSpec ns,
				    CapabilityEnvelope clock,
				    PermissionSet ps,
				    String comment)
    {
	Node retval;

	retval = (Node)KernelObjectCoroutine.
	    create(new Node(),
		   this.bdomain.getBDomainCoroutine(),
		   ns.toBytes(),
		   new CapabilityEnvelope[] {
		       clock,
		   },
		   comment,
		   ps);
	return retval;
    }

    public synchronized Node create(NodeSpec ns,
				    CapabilityEnvelope clock,
				    PermissionSet ps)
    {
	return this.create(ns, clock, ps, "Node");
    }
    
    public String toString()
    {
	return "NodeFactory["
	    + super.toString()
	    + "]";
    }
}
