/*
 * RemoteFlowEvent.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import java.io.IOException;

import bees.core.resource.Logger;

import bees.core.bdomain.BDomain;
import bees.core.bdomain.DeadBDomainException;

public final class RemoteFlowEvent
    extends TwoWayBeesEvent
{
    private byte domainDesc[];
    
    RemoteFlowEvent(RemoteFlowCoroutine rfc, byte domainDesc[])
    {
	super(rfc);
	
	this.domainDesc = domainDesc;
	this.setCoroutineClass(RemoteFlowCoroutine.class);
    }

    byte[] getFlowDesc()
    {
	return this.domainDesc;
    }

    protected void sendReply()
	throws DeadBDomainException
    {
	this.domainDesc = null;
	super.sendReply();
    }
    
    public Object clone()
    {
	Object retval = super.clone();
	RemoteFlowEvent rfe;

	rfe = (RemoteFlowEvent)retval;
	if( this.domainDesc != null )
	    rfe.domainDesc = (byte[])this.domainDesc.clone();
	return retval;
    }
    
    public String toString()
    {
	return "RemoteFlowEvent["
	    + super.toString()
	    + "; domainDesc="
	    + this.domainDesc
	    + "]";
    }
}
