/*
 * ResponderCoroutine.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

/**
 * A ResponderCoroutine is a Coroutine that automatically repeats state
 * transitions to a StateResponder specified in the Constructor.
 *
 * @see bees.core.StateResponder
 */
public abstract class ResponderCoroutine
    extends Coroutine
{
    /**
     * The StateResponder to notify of state changes.
     */
    private final StateResponder sr;

    /**
     * Construct a ResponderCoroutine with the given value.
     *
     * @param sr The StateResponder to notify of state changes.
     */
    public ResponderCoroutine(StateResponder sr)
    {
	this.sr = sr;
    }

    /**
     * @return The StateResponder to notify of state changes.
     */
    public StateResponder getResponder()
    {
	return this.sr;
    }

    /**
     * @see bees.core.Coroutine#setState(int)
     */
    protected synchronized void setState(int newState)
    {
	super.setState(newState);
	
	StateResponder.signal(this.sr, this, newState);
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
	return "ResponderCoroutine["
	    + super.toString()
	    + "; sr="
	    + this.sr
	    + "]";
    }
}
