/*
 * RevokeCapabilityEvent.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import bees.core.security.PermissionSet;

final class RevokeCapabilityEvent
    extends BeesEvent
{
    static final int METHOD_REVOKE = 0;
    static final int METHOD_DELETE = 1;

    private int method;
    private Class cl;
    private long id;
    private PermissionSet ps;
    
    RevokeCapabilityEvent(RevokeCapabilityCoroutine rcc,
			  Capability cap,
			  PermissionSet ps)
    {
	super(rcc);

	this.method = METHOD_REVOKE;
	this.cl = cap.getClass();
	this.id = cap.getID();
	this.ps = ps;
    }

    RevokeCapabilityEvent(RevokeCapabilityCoroutine rcc, Capability cap)
    {
	super(rcc);

	this.method = METHOD_DELETE;
	this.id = cap.getID();
    }

    void setMethod(int method)
    {
	this.method = method;
    }

    int getMethod()
    {
	return this.method;
    }

    Class getCapabilityClass()
    {
	return this.cl;
    }

    long getStoreID()
    {
	return this.id;
    }

    void setPermissions(PermissionSet ps)
    {
	this.ps = ps;
    }

    PermissionSet getPermissions()
    {
	return this.ps;
    }

    public Object clone()
    {
	Object retval = super.clone();
	RevokeCapabilityEvent rce;

	rce = (RevokeCapabilityEvent)retval;
	if( this.ps != null )
	    rce.ps = (PermissionSet)this.ps.clone();
	return retval;
    }
    
    public String toString()
    {
	return "RevokeCapabilityEvent["
	    + super.toString()
	    + "; method="
	    + this.method
	    + "; cl="
	    + this.cl
	    + "; id="
	    + this.id
	    + "; ps="
	    + this.ps
	    + "]";
    }
}
