/*
 * ANEPDemultiplexKey.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.anep;

import edu.utah.janos.nodeos.Domain;
import edu.utah.janos.nodeos.DemultiplexKey;

/**
 * Match ANEP packets with the specified protocolID and ANEP version.
 *
 * @author <a href="mailto:janos-discuss@flux.cs.utah.edu">Utah Janos Team</a>
 */
public class ANEPDemultiplexKey
    extends DemultiplexKey
{
    /**
     * Construct an ANEPDemultiplexKey that matches packets with the given
     * parameters.
     *
     * @param domain The current domain.
     * @param version The ANEP packet version.
     * @param protocolID The protocol ID to match.
     */
    public ANEPDemultiplexKey(Domain domain, byte version, short protocolID)
    {
	super(domain);
	
	this.addANEP(0, version, protocolID);
    }
    
    /**
     * Construct an ANEPDemultiplexKey with the given parameters.
     *
     * @param domain The current domain.
     * @param protocolID The protocol ID to match.
     */
    public ANEPDemultiplexKey(Domain domain, short protocolID)
    {
	this(domain, ANEPVersion.PACKET_VERSION, protocolID);
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
	return "ANEPDemultiplexKey["
	    + super.toString()
	    + "]";
    }
}
