#
# flow-builder-help.py
#
# Copyright (c) 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Bees Software.
#
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#

import os
import sys
import time
import beesPageTemplate

config = {
    "title" : "Flow Builder Help",
    "time" : time.ctime(os.stat(sys.argv[0])[8]),
    "help-file" : "root-help.html",
    }

body = """
<h2>Flow Builder Help</h2>
<p>

The flow builder creates a description of a protocol flow that can be used when
launching a protocol.  This description will follow the flow around and be
presented to authenticator applications when the protocol tries to spawn onto a
new node.  The tool works by reading a JAR file containing the protocol classes
and a "flow.properties" file.  Since there can be more than one flow in a JAR
you'll need to select the one you wish to build.  Next, the tool will parse the
properties file to figure out what capabilities are required by the flow and
what keys are required to sign the description.  The resulting description is
then written to a file capability.

<p>
The "Flow Builder" page is separated into four sections, JAR and flow
selection, flow description, authenticator parameters, and the capability
list.  The flow description section simply gives a short description of the
protocol and its version number.  It also provides a slot to enter the path of
the file capability where the manufactured description should be stored.  The
remaining sections are described below.

<h4>Authenticator Parameters</h4>

The main purpose of the flow description is to communicate with an
authenticator application.  This section provides a means to modify certain
arguments that the authenticator will look at to determine how to process the
flow.  Currently, the system only recognizes "source-auth" properties, which
are used by the included source based authenticator.  The list of properties
are as follows:

<ul>
<li>source - The source of the flow, this is expected to be the name of a
subdirectory in the "users" directory.  Also, the user's directory should
contain a "keys" subdirectory with key pairs for various algorithms.
<li>algorithm - The algorithm, and implied key pair, to use when signing the
flow.  <i>Note</i>:  DSA is the only tested algorithm, using RSA will most
likely not work.
</ul>

<h4>Authenticator Capability List</h4>

This section is used to tell the authenticator what extra capabilities the flow
would like to have access to.  For example, the Health protocol needs access to
the motherboard sensors, so it asks the authenticator for the "kaffe.sensors"
related package and class capabilities.  Because the description can be
cryptographically signed, the authenticator will only hand out privileged
capabilities to authorized flows.

<ul>
<li>Capability - A short description of the capability.
<li>Authenticator Parameters - The parameters the authenticator will pay
attention to when manipulating capabilities:
  <ul>
  <li>Source - The source of the capability, relative to the user's directory,
  or select objects from the root directory if the path starts with "global".
  <li>Destination - The destination name of the capability (optional).
  <li>Revoked permissions - The permissions to revoke from the capability.
  <li>Bound permissions - The bounding set of permissions for a capability.  In
  other words, the capability can have fewer permissions, but it will have no
  more than the given set.
  </ul>
<li>Authenticator Arguments - The values to pass to the authenticator for each
parameter.
</ul>

<h4>Manipulating Permissions</h4>

The revoked and bound permissions text areas mentioned in the previous section
are used to change the permissions of a capability.  For example, you can
revoke the write permission of a file capability before passing it to a new
protocol or you can bound the file to only have readability or appendiblity.
The format used to specify these permissions is the same as given to the
<file>apps.authenticator.FlowBuilder</file> application:

<ul>
<li>-permission &lt;name&gt;=&lt;actions&gt;
<li>-countPermission &lt;name&gt;=&lt;number&gt;
<li>{-intPermission, -minIntPermission, -maxIntPermission}
&lt;name&gt;=&lt;integer&gt;[;&lt;actions&gt;]
<li>-rangePermission
&lt;name&gt;=&lt;lo&gt;-&lt;hi&gt;[,&lt;lo&gt;-&lt;hi&gt;,... ;&lt;actions&gt;]
<li>{-floatPermission, -minFloatPermission, -maxFloatPermission}
&lt;name&gt;=&lt;float&gt;[;&lt;actions&gt;]
<li>-enumPermission &lt;name&gt;=&lt;string&gt;[;&lt;actions&gt;]
<li>-ipPermission &lt;name&gt;=&lt;ip address&gt;[;&lt;actions&gt;]
<li>-filePermission &lt;name&gt;=&lt;actions&gt;
</ul>

Where "name" depends on the type of capability, consult the source for the
definitive collection of properties, and "actions" are as follows:

<ul>
<li>read - Read the property.
<li>write - Write to the property.
<li>execute - Execute the property.
<li>append - Append to the property.
<li>list - Show the file in a listing (File only).
<li>create - Create a new file (File only).
<li>delete - Delete the file (File only).
</ul>

Examples:

<ul>
<li>-permission file=read - Permission to read the contents of a file.
<li>-permission file.length=read - Permission to read the length of a file.
<li>-ipPermission "address=192.168.0.2; read" - Permission to receive packets
from IP address 192.168.0.2
<li>-rangePermission "udp-port=10000-20000; read, write" - Permission to send
and receive packets using UDP ports 10000 through 20000.
<li>-minIntPermission "granularity=1000" - If used with a clock capability,
this specifies a minimum 1000 millisecond time granularity.
<li>-maxIntPermission "level=4; write" - If used with a logger capability, this
specifies a maximum logging level of four.
</ul>

"""

print beesPageTemplate.header % config

print body

print beesPageTemplate.footer % config
