/*
 * VirusBootCapsule.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package apps.virus;

import java.util.Enumeration;
import java.util.NoSuchElementException;

import java.io.IOException;

import bees.core.Xdr;
import bees.core.Node;
import bees.core.Capsule;
import bees.core.Neighbor;
import bees.core.ObjectMap;
import bees.core.NeighborImpl;
import bees.core.CapabilityEnvelope;
import bees.core.MulticastNeighborhood;
import bees.core.MissingCapabilityException;

import bees.core.resource.Logger;

/**
 * A VirusBootCapsule is used to initialize the virus domain.
 */
public final class VirusBootCapsule
    extends Capsule
{
    /**
     * Construct an empty VirusBootCapsule.
     */
    public VirusBootCapsule()
    {
    }

    public void encode(Xdr xdr)
    {
    }

    public void decode(Xdr xdr)
    {
    }

    public void evaluate(Node node)
    {
	MulticastNeighborhood mn;
	InfectCapsule ic;
	
	Logger.log(Logger.INFO, "Booting VirusProtocol.");
	mn = new MulticastNeighborhood();
	try
	{
	    Enumeration enum;
	    ObjectMap om;

	    om = node.getCapabilityMap("neighbors");
	    enum = om.elements();
	    while( enum.hasMoreElements() )
	    {
		try
		{
		    Neighbor n;

		    n = new Neighbor((NeighborImpl)enum.nextElement());
		    n.attachReceivers(this.getSession());
		    mn.addNeighbor(n.getNeighborImpl());
		}
		catch(IOException e)
		{
		    Logger.log(e);
		}
	    }
	}
	catch(NoSuchElementException e)
	{
	    CapabilityEnvelope ce[];

	    if( (ce = node.requestCapability("neighbors", "neighbors", null))
		!= null )
	    {
		int lpc;

		for( lpc = 0; lpc < ce.length; lpc++ )
		{
		    try
		    {
			Neighbor n;
			
			n = new Neighbor((NeighborImpl)ce[lpc].unseal());
			n.attachReceivers(this.getSession());
			mn.addNeighbor(n.getNeighborImpl());
		    }
		    catch(InstantiationException ie)
		    {
			Logger.log(ie);
		    }
		    catch(MissingCapabilityException mce)
		    {
			Logger.log(mce);
		    }
		    catch(IOException ioe)
		    {
			Logger.log(ioe);
		    }
		}
	    }
	    else
	    {
		Logger.log(Logger.WARNING, "No initial set of neighbors");
	    }
	}
	/* Create an infect capsule and add it to the cache. */
	ic = new InfectCapsule(mn);
	ic.fromCapsule(this);
	this.getSession().getCache().put(ic,
					 ic,
					 InfectCapsule.DEFAULT_INTERVAL);
    }

    public String toString()
    {
	return "VirusBootCapsule["
	    + super.toString()
	    + "]";
    }
}
