/*
 * VirusProtocol.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package apps.virus;

import bees.core.Panic;
import bees.core.Protocol;
import bees.core.DLProtocol;
import bees.core.IDTranslationProtocol;

import bees.core.security.Permission;
import bees.core.security.PermissionSet;
import bees.core.security.CountPermission;
import bees.core.security.MinimumIntegerPermission;

/**
 * The VirusProtocol is just a simple protocol that spreads itself to any
 * immediate neighbors.
 */
public final class VirusProtocol
    extends Protocol
{
    /**
     * Construct the VirusProtocol description.
     */
    public VirusProtocol()
    {
	try
	{
	    this.startProtocolDefn();
	    {
		this.addCapsule("apps.virus.InfectCapsule",
				new PermissionSet(new Permission[] {
				    new CountPermission("neighborhood", 1),
				    new MinimumIntegerPermission("interval",
								 500),
				}));
		this.setBootStrap("apps.virus.VirusBootCapsule",
				  new PermissionSet(new Permission[] {
				      new CountPermission("transforms", 1),
				  }));
		this.setSession("apps.virus.VirusSession");
		this.addCompanion(new DLProtocol());
		this.addCompanion(new IDTranslationProtocol());
	    }
	    this.endProtocolDefn();
	}
	catch(ClassNotFoundException e)
	{
	    throw new Panic(e);
	}
    }

    public String toString()
    {
	return "VirusProtocol["
	    + super.toString()
	    + "]";
    }
}
